Exception: Knock::APIError

Inherits:
KnockError show all
Defined in:
lib/knock/errors.rb

Overview

APIError is a generic error that may be raised in cases where none of the other named errors cover the problem. It could also be raised in the case that a new error has been introduced in the API, but this version of the Ruby SDK doesn't know how to handle it.

Instance Attribute Summary

Attributes inherited from KnockError

#http_status, #request_id

Method Summary

Methods inherited from KnockError

#initialize, #to_s

Constructor Details

This class inherits a constructor from Knock::KnockError