Class: Knockapi::Models::AudienceMemberRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::AudienceMemberRequest
- Defined in:
- lib/knockapi/models/audience_member_request.rb,
sig/knockapi/models/audience_member_request.rbs
Instance Attribute Summary collapse
-
#tenant ⇒ String?
The unique identifier for the tenant.
-
#user ⇒ Knockapi::Models::InlineIdentifyUserRequest
A set of parameters to inline-identify a user with.
Instance Method Summary collapse
-
#initialize(user:, tenant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AudienceMemberRequest for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user:, tenant: nil) ⇒ Object
Some parameter documentations has been truncated, see Knockapi::Models::AudienceMemberRequest for more details.
An audience member.
|
|
# File 'lib/knockapi/models/audience_member_request.rb', line 21
|
Instance Attribute Details
#tenant ⇒ String?
The unique identifier for the tenant.
19 |
# File 'lib/knockapi/models/audience_member_request.rb', line 19 optional :tenant, String, nil?: true |
#user ⇒ Knockapi::Models::InlineIdentifyUserRequest
A set of parameters to inline-identify a user with. Inline identifying the user will ensure that the user is available before the request is executed in Knock. It will perform an upsert for the user you're supplying, replacing any properties specified.
13 |
# File 'lib/knockapi/models/audience_member_request.rb', line 13 required :user, -> { Knockapi::InlineIdentifyUserRequest } |
Instance Method Details
#to_hash ⇒ {
16 |
# File 'sig/knockapi/models/audience_member_request.rbs', line 16
def to_hash: -> {
|