Class: Knockapi::Models::AudienceRemoveMembersParams::Member
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::AudienceRemoveMembersParams::Member
- Defined in:
- lib/knockapi/models/audience_remove_members_params.rb,
sig/knockapi/models/audience_remove_members_params.rbs
Instance Attribute Summary collapse
-
#tenant ⇒ String?
The unique identifier for the tenant.
-
#user ⇒ Knockapi::Models::InlineIdentifyUserRequest
A set of parameters to inline-identify a user with.
Instance Method Summary collapse
-
#initialize(user:, tenant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Member for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(user:, tenant: nil) ⇒ Object
Some parameter documentations has been truncated, see Knockapi::Models::AudienceRemoveMembersParams::Member for more details.
An audience member.
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/knockapi/models/audience_remove_members_params.rb', line 32 class Member < Knockapi::Internal::Type::BaseModel # @!attribute user # A set of parameters to inline-identify a user with. Inline identifying the user # will ensure that the user is available before the request is executed in Knock. # It will perform an upsert for the user you're supplying, replacing any # properties specified. # # @return [Knockapi::Models::InlineIdentifyUserRequest] required :user, -> { Knockapi::InlineIdentifyUserRequest } # @!attribute tenant # The unique identifier for the tenant. # # @return [String, nil] optional :tenant, String, nil?: true # @!method initialize(user:, tenant: nil) # Some parameter documentations has been truncated, see # {Knockapi::Models::AudienceRemoveMembersParams::Member} for more details. # # An audience member. # # @param user [Knockapi::Models::InlineIdentifyUserRequest] A set of parameters to inline-identify a user with. Inline identifying the user # # @param tenant [String, nil] The unique identifier for the tenant. end |
Instance Attribute Details
#tenant ⇒ String?
The unique identifier for the tenant.
46 |
# File 'lib/knockapi/models/audience_remove_members_params.rb', line 46 optional :tenant, String, nil?: true |
#user ⇒ Knockapi::Models::InlineIdentifyUserRequest
A set of parameters to inline-identify a user with. Inline identifying the user will ensure that the user is available before the request is executed in Knock. It will perform an upsert for the user you're supplying, replacing any properties specified.
40 |
# File 'lib/knockapi/models/audience_remove_members_params.rb', line 40 required :user, -> { Knockapi::InlineIdentifyUserRequest } |
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/knockapi/models/audience_remove_members_params.rbs', line 43
def to_hash: -> {
|