Class: Knockapi::Models::Channels::BulkUpdateMessageStatusParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/knockapi/models/channels/bulk_update_message_status_params.rb,
sig/knockapi/models/channels/bulk_update_message_status_params.rbs

Overview

See Also:

  • Knockapi::Resources::Channels::Bulk#update_message_status

Defined Under Namespace

Modules: Action, Archived, DeliveryStatus, EngagementStatus

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



75
# File 'sig/knockapi/models/channels/bulk_update_message_status_params.rbs', line 75

def initialize: (

Instance Attribute Details

#actionSymbol, Knockapi::Models::Channels::BulkUpdateMessageStatusParams::Action

Parameters:

  • value (Knockapi::Models::Channels::BulkUpdateMessageStatusParams::action)

Returns:



19
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 19

required :action, enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::Action }

#archivedSymbol, ...

Limits the results to messages with the given archived status.



25
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 25

optional :archived, enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::Archived }

#channel_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 14

required :channel_id, String

#delivery_statusSymbol, ...

Limits the results to messages with the given delivery status.



31
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 31

optional :delivery_status, enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::DeliveryStatus }

#engagement_statusSymbol, ...

Limits the results to messages with the given engagement status.



37
38
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 37

optional :engagement_status,
enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::EngagementStatus }

#has_tenantBoolean?

Limits the results to messages that have a tenant or not.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


44
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 44

optional :has_tenant, Knockapi::Internal::Type::Boolean

#newer_thanTime?

Limits the results to messages inserted after the given date.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


50
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 50

optional :newer_than, Time

#older_thanTime?

Limits the results to messages inserted before the given date.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


56
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 56

optional :older_than, Time

#recipient_idsArray<String>?

Limits the results to messages with the given recipient IDs.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


62
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 62

optional :recipient_ids, Knockapi::Internal::Type::ArrayOf[String]

#tenantsArray<String>?

Limits the results to messages with the given tenant IDs.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


68
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 68

optional :tenants, Knockapi::Internal::Type::ArrayOf[String]

#trigger_dataString?

Limits the results to only messages that were generated with the given data. See trigger data filtering for more information.

Parameters:

  • (String)

Returns:

  • (String, nil)


76
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 76

optional :trigger_data, String

#workflowsArray<String>?

Limits the results to messages with the given workflow keys.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


82
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 82

optional :workflows, Knockapi::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 128

Instance Method Details

#to_hash{

Returns:

  • ({)


91
# File 'sig/knockapi/models/channels/bulk_update_message_status_params.rbs', line 91

def to_hash: -> {