Class: Knockapi::Models::MessageContents::Data::MessageInAppFeedContent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::MessageContents::Data::MessageInAppFeedContent
- Defined in:
- lib/knockapi/models/message_contents.rb,
sig/knockapi/models/message_contents.rbs
Defined Under Namespace
Modules: Block
Constant Summary collapse
- Knockapi =
Instance Attribute Summary collapse
-
#_typename ⇒ String
The typename of the schema.
-
#blocks ⇒ Array<Knockapi::Models::MessageInAppFeedContentBlock, Knockapi::Models::MessageInAppFeedButtonSetBlock>
The blocks of the message in an app feed.
Instance Method Summary collapse
-
#initialize(_typename:, blocks:) ⇒ Object
constructor
The content of an in-app feed message.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(_typename:, blocks:) ⇒ Object
The content of an in-app feed message.
|
|
# File 'lib/knockapi/models/message_contents.rb', line 343
|
Instance Attribute Details
#_typename ⇒ String
The typename of the schema.
334 |
# File 'lib/knockapi/models/message_contents.rb', line 334 required :_typename, String, api_name: :__typename |
#blocks ⇒ Array<Knockapi::Models::MessageInAppFeedContentBlock, Knockapi::Models::MessageInAppFeedButtonSetBlock>
The blocks of the message in an app feed.
340 341 |
# File 'lib/knockapi/models/message_contents.rb', line 340 required :blocks, -> { Knockapi::Internal::Type::ArrayOf[union: Knockapi::MessageContents::Data::MessageInAppFeedContent::Block] } |
Instance Method Details
#to_hash ⇒ {
266 |
# File 'sig/knockapi/models/message_contents.rbs', line 266
def to_hash: -> {
|