Class: Knockapi::Models::MessageDeliveryLog::Response

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/message_delivery_log.rb,
sig/knockapi/models/message_delivery_log.rbs

Overview

See Also:

  • Knockapi::Models::MessageDeliveryLog#response

Defined Under Namespace

Modules: Body

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(body: nil, headers: nil, status: nil) ⇒ Object

A message delivery log response.

Parameters:

  • body (String, Hash{Symbol=>Object}) (defaults to: nil)

    The body content that was received with the response.

  • headers (Hash{Symbol=>Object}, nil) (defaults to: nil)

    The headers that were received with the response.

  • status (Integer) (defaults to: nil)

    The HTTP status code of the response.



# File 'lib/knockapi/models/message_delivery_log.rb', line 174

Instance Attribute Details

#bodyString, ...

The body content that was received with the response.

Returns:

  • (String, Hash{Symbol=>Object}, nil)


160
# File 'lib/knockapi/models/message_delivery_log.rb', line 160

optional :body, union: -> { Knockapi::MessageDeliveryLog::Response::Body }

#headersHash{Symbol=>Object}?

The headers that were received with the response.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:



166
# File 'lib/knockapi/models/message_delivery_log.rb', line 166

optional :headers, Knockapi::Internal::Type::HashOf[Knockapi::Internal::Type::Unknown], nil?: true

#statusInteger?

The HTTP status code of the response.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


172
# File 'lib/knockapi/models/message_delivery_log.rb', line 172

optional :status, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


153
# File 'sig/knockapi/models/message_delivery_log.rbs', line 153

def to_hash: -> {