Class: Knockapi::Models::MessageInAppFeedButtonSetBlock

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/message_in_app_feed_button_set_block.rb,
sig/knockapi/models/message_in_app_feed_button_set_block.rbs

Defined Under Namespace

Modules: Type Classes: Button

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(action:, label:, name:) ⇒ Object

A button in an in app feed message.

Parameters:

  • action (String) —

    The action to take when the button is clicked.

  • label (String) —

    The label of the button.

  • name (String) —

    The name of the button.



# File 'lib/knockapi/models/message_in_app_feed_button_set_block.rb', line 53

Instance Attribute Details

#buttons ⇒ Array<Knockapi::Models::MessageInAppFeedButtonSetBlock::Button>

A list of buttons in an in app feed message.

Parameters:

  • value (::Array[Knockapi::MessageInAppFeedButtonSetBlock::Button])

Returns:



10
11
# File 'lib/knockapi/models/message_in_app_feed_button_set_block.rb', line 10

required :buttons,
-> { Knockapi::Internal::Type::ArrayOf[Knockapi::MessageInAppFeedButtonSetBlock::Button] }

#name ⇒ String

The name of the button set in a message in an app feed.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/knockapi/models/message_in_app_feed_button_set_block.rb', line 17

required :name, String

#type ⇒ Symbol, Knockapi::Models::MessageInAppFeedButtonSetBlock::Type

The type of block in a message in an app feed.

Parameters:

  • value (Knockapi::Models::MessageInAppFeedButtonSetBlock::type_)

Returns:



23
# File 'lib/knockapi/models/message_in_app_feed_button_set_block.rb', line 23

required :type, enum: -> { Knockapi::MessageInAppFeedButtonSetBlock::Type }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


23
# File 'sig/knockapi/models/message_in_app_feed_button_set_block.rbs', line 23

def to_hash: -> {