Class: Knockapi::Models::MessageInAppFeedContentBlock

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/message_in_app_feed_content_block.rb,
sig/knockapi/models/message_in_app_feed_content_block.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, name:, rendered:, type:) ⇒ Object

A block in a message in an app feed.

Parameters:

  • content (String) —

    The content of the block in a message in an app feed.

  • name (String) —

    The name of the block in a message in an app feed.

  • rendered (String) —

    The rendered HTML version of the content.

  • type (Symbol, Knockapi::Models::MessageInAppFeedContentBlock::Type) —

    The type of block in a message in an app feed.



# File 'lib/knockapi/models/message_in_app_feed_content_block.rb', line 30

Instance Attribute Details

#content ⇒ String

The content of the block in a message in an app feed.

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/knockapi/models/message_in_app_feed_content_block.rb', line 10

required :content, String

#name ⇒ String

The name of the block in a message in an app feed.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/knockapi/models/message_in_app_feed_content_block.rb', line 16

required :name, String

#rendered ⇒ String

The rendered HTML version of the content.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/knockapi/models/message_in_app_feed_content_block.rb', line 22

required :rendered, String

#type ⇒ Symbol, Knockapi::Models::MessageInAppFeedContentBlock::Type

The type of block in a message in an app feed.

Parameters:

  • value (Knockapi::Models::MessageInAppFeedContentBlock::type_)

Returns:



28
# File 'lib/knockapi/models/message_in_app_feed_content_block.rb', line 28

required :type, enum: -> { Knockapi::MessageInAppFeedContentBlock::Type }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


27
# File 'sig/knockapi/models/message_in_app_feed_content_block.rbs', line 27

def to_hash: -> {