Module: Knockapi::Models::MessageListParams::EngagementStatus

Extended by:
Internal::Type::Enum
Defined in:
lib/knockapi/models/message_list_params.rb,
sig/knockapi/models/message_list_params.rbs

Constant Summary collapse

SEEN =

Returns:

  • (:seen)
:seen
UNSEEN =

Returns:

  • (:unseen)
:unseen
READ =

Returns:

  • (:read)
:read
UNREAD =

Returns:

  • (:unread)
:unread
ARCHIVED =

Returns:

  • (:archived)
:archived
UNARCHIVED =

Returns:

  • (:unarchived)
:unarchived
:link_clicked
INTERACTED =

Returns:

  • (:interacted)
:interacted

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(after: nil, before: nil, channel_id: nil, engagement_status: nil, inserted_at: nil, message_ids: nil, page_size: nil, source: nil, status: nil, tenant: nil, trigger_data: nil, workflow_categories: nil, workflow_recipient_run_id: nil, workflow_run_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Knockapi::Models::MessageListParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    The cursor to fetch entries after.

  • before (String) (defaults to: nil)

    The cursor to fetch entries before.

  • channel_id (String) (defaults to: nil)

    Limits the results to items with the corresponding channel ID.

  • engagement_status (Array<Symbol, Knockapi::Models::MessageListParams::EngagementStatus>) (defaults to: nil)

    Limits the results to messages with the given engagement status.

  • inserted_at (Knockapi::Models::MessageListParams::InsertedAt) (defaults to: nil)
  • message_ids (Array<String>) (defaults to: nil)

    Limits the results to only the message IDs given (max 50). Note: when using this

  • page_size (Integer) (defaults to: nil)

    The number of items per page (defaults to 50).

  • source (String) (defaults to: nil)

    Limits the results to messages triggered by the given workflow key.

  • status (Array<Symbol, Knockapi::Models::MessageListParams::Status>) (defaults to: nil)

    Limits the results to messages with the given delivery status.

  • tenant (String) (defaults to: nil)

    Limits the results to items with the corresponding tenant.

  • trigger_data (String) (defaults to: nil)

    Limits the results to only messages that were generated with the given data. See

  • workflow_categories (Array<String>) (defaults to: nil)

    Limits the results to messages related to any of the provided categories.

  • workflow_recipient_run_id (String) (defaults to: nil)

    Limits the results to messages for a specific recipient's workflow run.

  • workflow_run_id (String) (defaults to: nil)

    Limits the results to messages associated with the top-level workflow run ID ret

  • request_options (Knockapi::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/knockapi/models/message_list_params.rb', line 132

module EngagementStatus
  extend Knockapi::Internal::Type::Enum

  SEEN = :seen
  UNSEEN = :unseen
  READ = :read
  UNREAD = :unread
  ARCHIVED = :archived
  UNARCHIVED = :unarchived
  LINK_CLICKED = :link_clicked
  INTERACTED = :interacted

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Knockapi::Models::MessageListParams::engagement_status]

Returns:

  • (::Array[Knockapi::Models::MessageListParams::engagement_status])


146
# File 'sig/knockapi/models/message_list_params.rbs', line 146

def self?.values: -> ::Array[Knockapi::Models::MessageListParams::engagement_status]