Class: Knockapi::Models::MessageListParams::InsertedAt
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::MessageListParams::InsertedAt
- Defined in:
- lib/knockapi/models/message_list_params.rb,
sig/knockapi/models/message_list_params.rbs
Instance Attribute Summary collapse
-
#gt ⇒ String?
Limits the results to items inserted after the given date.
-
#gte ⇒ String?
Limits the results to items inserted after or on the given date.
-
#lt ⇒ String?
Limits the results to items inserted before the given date.
-
#lte ⇒ String?
Limits the results to items inserted before or on the given date.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
168 |
# File 'sig/knockapi/models/message_list_params.rbs', line 168
def initialize: (
|
Instance Attribute Details
#gt ⇒ String?
Limits the results to items inserted after the given date.
153 |
# File 'lib/knockapi/models/message_list_params.rb', line 153 optional :gt, String |
#gte ⇒ String?
Limits the results to items inserted after or on the given date.
159 |
# File 'lib/knockapi/models/message_list_params.rb', line 159 optional :gte, String |
#lt ⇒ String?
Limits the results to items inserted before the given date.
165 |
# File 'lib/knockapi/models/message_list_params.rb', line 165 optional :lt, String |
#lte ⇒ String?
Limits the results to items inserted before or on the given date.
171 |
# File 'lib/knockapi/models/message_list_params.rb', line 171 optional :lte, String |
Instance Method Details
#to_hash ⇒ { gt: String, gte: String, lt: String, lte: String }
175 |
# File 'sig/knockapi/models/message_list_params.rbs', line 175
def to_hash: -> { gt: String, gte: String, lt: String, lte: String }
|