Class: Knockapi::Models::ObjectListMessagesParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/knockapi/models/object_list_messages_params.rb,
sig/knockapi/models/object_list_messages_params.rbs

Overview

See Also:

  • Knockapi::Resources::Objects#list_messages

Defined Under Namespace

Modules: EngagementStatus, Status Classes: InsertedAt

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Object

Parameters:

  • gt (String) (defaults to: nil)

    Limits the results to items inserted after the given date.

  • gte (String) (defaults to: nil)

    Limits the results to items inserted after or on the given date.

  • lt (String) (defaults to: nil)

    Limits the results to items inserted before the given date.

  • lte (String) (defaults to: nil)

    Limits the results to items inserted before or on the given date.



# File 'lib/knockapi/models/object_list_messages_params.rb', line 188

Instance Attribute Details

#afterString?

The cursor to fetch entries after.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/knockapi/models/object_list_messages_params.rb', line 24

optional :after, String

#beforeString?

The cursor to fetch entries before.

Parameters:

  • (String)

Returns:

  • (String, nil)


30
# File 'lib/knockapi/models/object_list_messages_params.rb', line 30

optional :before, String

#channel_idString?

Limits the results to items with the corresponding channel ID.

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/knockapi/models/object_list_messages_params.rb', line 36

optional :channel_id, String

#collectionString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/knockapi/models/object_list_messages_params.rb', line 13

required :collection, String

#engagement_statusArray<Symbol, Knockapi::Models::ObjectListMessagesParams::EngagementStatus>?

Limits the results to messages with the given engagement status.



42
43
# File 'lib/knockapi/models/object_list_messages_params.rb', line 42

optional :engagement_status,
-> { Knockapi::Internal::Type::ArrayOf[enum: Knockapi::ObjectListMessagesParams::EngagementStatus] }

#idString

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/knockapi/models/object_list_messages_params.rb', line 18

required :id, String

#inserted_atKnockapi::Models::ObjectListMessagesParams::InsertedAt?



48
# File 'lib/knockapi/models/object_list_messages_params.rb', line 48

optional :inserted_at, -> { Knockapi::ObjectListMessagesParams::InsertedAt }

#message_idsArray<String>?

Limits the results to only the message IDs given (max 50). Note: when using this option, the results will be subject to any other filters applied to the query.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


55
# File 'lib/knockapi/models/object_list_messages_params.rb', line 55

optional :message_ids, Knockapi::Internal::Type::ArrayOf[String]

#page_sizeInteger?

The number of items per page (defaults to 50).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


61
# File 'lib/knockapi/models/object_list_messages_params.rb', line 61

optional :page_size, Integer

#sourceString?

Limits the results to messages triggered by the given workflow key.

Parameters:

  • (String)

Returns:

  • (String, nil)


67
# File 'lib/knockapi/models/object_list_messages_params.rb', line 67

optional :source, String

#statusArray<Symbol, Knockapi::Models::ObjectListMessagesParams::Status>?

Limits the results to messages with the given delivery status.



73
74
# File 'lib/knockapi/models/object_list_messages_params.rb', line 73

optional :status,
-> { Knockapi::Internal::Type::ArrayOf[enum: Knockapi::ObjectListMessagesParams::Status] }

#tenantString?

Limits the results to items with the corresponding tenant.

Parameters:

  • (String)

Returns:

  • (String, nil)


80
# File 'lib/knockapi/models/object_list_messages_params.rb', line 80

optional :tenant, String

#trigger_dataString?

Limits the results to only messages that were generated with the given data. See trigger data filtering for more information.

Parameters:

  • (String)

Returns:

  • (String, nil)


88
# File 'lib/knockapi/models/object_list_messages_params.rb', line 88

optional :trigger_data, String

#workflow_categoriesArray<String>?

Limits the results to messages related to any of the provided categories.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


94
# File 'lib/knockapi/models/object_list_messages_params.rb', line 94

optional :workflow_categories, Knockapi::Internal::Type::ArrayOf[String]

#workflow_recipient_run_idString?

Limits the results to messages for a specific recipient's workflow run.

Parameters:

  • (String)

Returns:

  • (String, nil)


100
# File 'lib/knockapi/models/object_list_messages_params.rb', line 100

optional :workflow_recipient_run_id, String

#workflow_run_idString?

Limits the results to messages associated with the top-level workflow run ID returned by the workflow trigger request.

Parameters:

  • (String)

Returns:

  • (String, nil)


107
# File 'lib/knockapi/models/object_list_messages_params.rb', line 107

optional :workflow_run_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/knockapi/models/object_list_messages_params.rb', line 159

Instance Method Details

#to_hash{

Returns:

  • ({)


114
# File 'sig/knockapi/models/object_list_messages_params.rbs', line 114

def to_hash: -> {