Class: Knockapi::Models::ObjectListSubscriptionsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::ObjectListSubscriptionsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/object_list_subscriptions_params.rb,
sig/knockapi/models/object_list_subscriptions_params.rbs
Overview
Defined Under Namespace
Modules: Include, Mode Classes: Object
Instance Attribute Summary collapse
-
#after ⇒ String?
The cursor to fetch entries after.
-
#before ⇒ String?
The cursor to fetch entries before.
- #collection ⇒ String
-
#include ⇒ Array<Symbol, Knockapi::Models::ObjectListSubscriptionsParams::Include>?
Additional fields to include in the response.
-
#mode ⇒ Symbol, ...
Mode of the request.
- #object_id_ ⇒ String
-
#objects ⇒ Array<Knockapi::Models::ObjectListSubscriptionsParams::Object>?
Objects to filter by (only used if mode is
recipient). -
#page_size ⇒ Integer?
The number of items per page (defaults to 50).
-
#recipients ⇒ Array<String, Knockapi::Models::RecipientReference::ObjectReference>?
Recipients to filter by (only used if mode is
object).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
61 |
# File 'sig/knockapi/models/object_list_subscriptions_params.rbs', line 61
def initialize: (
|
Instance Attribute Details
#after ⇒ String?
The cursor to fetch entries after.
24 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 24 optional :after, String |
#before ⇒ String?
The cursor to fetch entries before.
30 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 30 optional :before, String |
#collection ⇒ String
13 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 13 required :collection, String |
#include ⇒ Array<Symbol, Knockapi::Models::ObjectListSubscriptionsParams::Include>?
Additional fields to include in the response.
36 37 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 36 optional :include, -> { Knockapi::Internal::Type::ArrayOf[enum: Knockapi::ObjectListSubscriptionsParams::Include] } |
#mode ⇒ Symbol, ...
Mode of the request. recipient to list the objects that the provided object is
subscribed to, object to list the recipients that subscribe to the provided
object.
45 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 45 optional :mode, enum: -> { Knockapi::ObjectListSubscriptionsParams::Mode } |
#object_id_ ⇒ String
18 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 18 required :object_id_, String |
#objects ⇒ Array<Knockapi::Models::ObjectListSubscriptionsParams::Object>?
Objects to filter by (only used if mode is recipient).
51 52 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 51 optional :objects, -> { Knockapi::Internal::Type::ArrayOf[Knockapi::ObjectListSubscriptionsParams::Object] } |
#page_size ⇒ Integer?
The number of items per page (defaults to 50).
58 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 58 optional :page_size, Integer |
#recipients ⇒ Array<String, Knockapi::Models::RecipientReference::ObjectReference>?
Recipients to filter by (only used if mode is object).
64 |
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 64 optional :recipients, -> { Knockapi::Internal::Type::ArrayOf[union: Knockapi::RecipientReference] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/knockapi/models/object_list_subscriptions_params.rb', line 95
|
Instance Method Details
#to_hash ⇒ {
74 |
# File 'sig/knockapi/models/object_list_subscriptions_params.rbs', line 74
def to_hash: -> {
|