Class: Knockapi::Models::ObjectSetParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/knockapi/models/object_set_params.rb,
sig/knockapi/models/object_set_params.rbs

Overview

See Also:

  • Knockapi::Resources::Objects#set

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(collection:, id:, channel_data: nil, locale: nil, name: nil, preferences: nil, timezone: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Knockapi::Models::ObjectSetParams for more details.

Parameters:



# File 'lib/knockapi/models/object_set_params.rb', line 57

Instance Attribute Details

#collectionString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/knockapi/models/object_set_params.rb', line 13

required :collection, String

#idString

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/knockapi/models/object_set_params.rb', line 18

required :id, String

#localeString?

The locale of the object. Used for message localization.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/knockapi/models/object_set_params.rb', line 32

optional :locale, String, nil?: true

#nameString?

An optional name for the object.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/knockapi/models/object_set_params.rb', line 38

optional :name, String, nil?: true

#preferencesHash{Symbol=>Knockapi::Models::Recipients::PreferenceSetRequest}?

Inline set preferences for a recipient, where the key is the preference set id. Preferences that are set inline will be merged into any existing preferences rather than replacing them.



46
# File 'lib/knockapi/models/object_set_params.rb', line 46

optional :preferences, -> { Knockapi::Internal::Type::HashOf[Knockapi::Recipients::PreferenceSetRequest] }

#timezoneString?

The timezone of the object. Must be a valid tz database time zone string. Used for recurring schedules.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


55
# File 'lib/knockapi/models/object_set_params.rb', line 55

optional :timezone, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/knockapi/models/object_set_params.rbs', line 52

def to_hash: -> {