Class: Knockapi::Models::Providers::MsTeamCheckAuthResponse::Connection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/providers/ms_team_check_auth_response.rb,
sig/knockapi/models/providers/ms_team_check_auth_response.rbs

Overview

See Also:

  • Knockapi::Models::Providers::MsTeamCheckAuthResponse#connection

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ok:, ms_teams_tenant_id: nil, reason: nil) ⇒ Object

A Microsoft Teams connection object.

Parameters:

  • ok (Boolean)

    Whether the Microsoft Teams connection is valid.

  • ms_teams_tenant_id (String, nil) (defaults to: nil)

    The Microsoft Teams tenant ID for the connected tenant.

  • reason (String, nil) (defaults to: nil)

    The reason for the Microsoft Teams connection if it is not valid.



# File 'lib/knockapi/models/providers/ms_team_check_auth_response.rb', line 39

Instance Attribute Details

#ms_teams_tenant_idString?

The Microsoft Teams tenant ID for the connected tenant.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


31
# File 'lib/knockapi/models/providers/ms_team_check_auth_response.rb', line 31

optional :ms_teams_tenant_id, String, nil?: true

#okBoolean

Whether the Microsoft Teams connection is valid.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


25
# File 'lib/knockapi/models/providers/ms_team_check_auth_response.rb', line 25

required :ok, Knockapi::Internal::Type::Boolean

#reasonString?

The reason for the Microsoft Teams connection if it is not valid.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


37
# File 'lib/knockapi/models/providers/ms_team_check_auth_response.rb', line 37

optional :reason, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/knockapi/models/providers/ms_team_check_auth_response.rbs', line 36

def to_hash: -> {