Class: Knockapi::Models::Recipients::AwsSnsPushChannelDataDevicesOnly::Device

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/recipients/aws_sns_push_channel_data_devices_only.rb,
sig/knockapi/models/recipients/aws_sns_push_channel_data_devices_only.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(target_arn:, locale: nil, timezone: nil) ⇒ Object

Some parameter documentations has been truncated, see Knockapi::Models::Recipients::AwsSnsPushChannelDataDevicesOnly::Device for more details.

Parameters:

  • target_arn (String)

    The ARN of a platform endpoint associated with a platform application and a devi

  • locale (String, nil) (defaults to: nil)

    The locale of the object. Used for [message localization](/concepts/translations

  • timezone (String, nil) (defaults to: nil)

    The timezone of the object. Must be a valid [tz database time zone string](https



24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/knockapi/models/recipients/aws_sns_push_channel_data_devices_only.rb', line 24

class Device < Knockapi::Internal::Type::BaseModel
  # @!attribute target_arn
  #   The ARN of a platform endpoint associated with a platform application and a
  #   device token. See
  #   [Setting up an Amazon SNS platform endpoint for mobile notifications](https://docs.aws.amazon.com/sns/latest/dg/mobile-platform-endpoint.html).
  #
  #   @return [String]
  required :target_arn, String

  # @!attribute locale
  #   The locale of the object. Used for
  #   [message localization](/concepts/translations).
  #
  #   @return [String, nil]
  optional :locale, String, nil?: true

  # @!attribute timezone
  #   The timezone of the object. Must be a
  #   valid [tz database time zone string](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones).
  #   Used
  #   for [recurring schedules](/concepts/schedules#scheduling-workflows-with-recurring-schedules-for-recipients).
  #
  #   @return [String, nil]
  optional :timezone, String, nil?: true

  # @!method initialize(target_arn:, locale: nil, timezone: nil)
  #   Some parameter documentations has been truncated, see
  #   {Knockapi::Models::Recipients::AwsSnsPushChannelDataDevicesOnly::Device} for
  #   more details.
  #
  #   @param target_arn [String] The ARN of a platform endpoint associated with a platform application and a devi
  #
  #   @param locale [String, nil] The locale of the object. Used for [message localization](/concepts/translations
  #
  #   @param timezone [String, nil] The timezone of the object. Must be a valid [tz database time zone string](https
end

Instance Attribute Details

#localeString?

The locale of the object. Used for message localization.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/knockapi/models/recipients/aws_sns_push_channel_data_devices_only.rb', line 38

optional :locale, String, nil?: true

#target_arnString

The ARN of a platform endpoint associated with a platform application and a device token. See Setting up an Amazon SNS platform endpoint for mobile notifications.

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/knockapi/models/recipients/aws_sns_push_channel_data_devices_only.rb', line 31

required :target_arn, String

#timezoneString?

The timezone of the object. Must be a valid tz database time zone string. Used for recurring schedules.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/knockapi/models/recipients/aws_sns_push_channel_data_devices_only.rb', line 47

optional :timezone, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/knockapi/models/recipients/aws_sns_push_channel_data_devices_only.rbs', line 35

def to_hash: -> {