Class: Knockapi::Models::Recipients::PreferenceSetChannelSetting
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Recipients::PreferenceSetChannelSetting
- Defined in:
- lib/knockapi/models/recipients/preference_set_channel_setting.rb,
sig/knockapi/models/recipients/preference_set_channel_setting.rbs
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Knockapi::Models::Condition>
A list of conditions to apply to a specific channel.
Instance Method Summary collapse
-
#initialize(conditions:) ⇒ PreferenceSetChannelSetting
constructor
A set of settings for a specific channel.
- #to_hash ⇒ { conditions: ::Array[Knockapi::Condition] }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(conditions:) ⇒ PreferenceSetChannelSetting
A set of settings for a specific channel. Currently, this can only be a list of conditions to apply.
|
|
# File 'lib/knockapi/models/recipients/preference_set_channel_setting.rb', line 13
|
Instance Attribute Details
#conditions ⇒ Array<Knockapi::Models::Condition>
A list of conditions to apply to a specific channel.
11 |
# File 'lib/knockapi/models/recipients/preference_set_channel_setting.rb', line 11 required :conditions, -> { Knockapi::Internal::Type::ArrayOf[Knockapi::Condition] } |
Instance Method Details
#to_hash ⇒ { conditions: ::Array[Knockapi::Condition] }
12 |
# File 'sig/knockapi/models/recipients/preference_set_channel_setting.rbs', line 12
def to_hash: -> { conditions: ::Array[Knockapi::Condition] }
|