Module: Knockapi::Models::Recipients::PreferenceSetRequest::CommercialSubscribed
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/knockapi/models/recipients/preference_set_request.rb,
sig/knockapi/models/recipients/preference_set_request.rbs
Overview
Whether the recipient is subscribed to commercial communications. When false, the recipient will not receive commercial workflow notifications. Can also be set to a settings object with conditions that are evaluated at notification send time.
Instance Method Summary collapse
- #self?.variants ⇒ ::Array[Knockapi::Models::Recipients::PreferenceSetRequest::commercial_subscribed]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.variants ⇒ ::Array[Knockapi::Models::Recipients::PreferenceSetRequest::commercial_subscribed]
120 |
# File 'sig/knockapi/models/recipients/preference_set_request.rbs', line 120
def self?.variants: -> ::Array[Knockapi::Models::Recipients::PreferenceSetRequest::commercial_subscribed]
|