Class: Knockapi::Models::Recipients::SlackChannelData::Connection::SlackIncomingWebhookConnection::IncomingWebhook
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Recipients::SlackChannelData::Connection::SlackIncomingWebhookConnection::IncomingWebhook
- Defined in:
- lib/knockapi/models/recipients/slack_channel_data.rb,
sig/knockapi/models/recipients/slack_channel_data.rbs
Overview
Instance Attribute Summary collapse
-
#url ⇒ String
The URL of the incoming webhook for a Slack connection.
Instance Method Summary collapse
-
#initialize ⇒ IncomingWebhook
constructor
A new instance of IncomingWebhook.
- #to_hash ⇒ { url: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ IncomingWebhook
Returns a new instance of IncomingWebhook.
76 |
# File 'sig/knockapi/models/recipients/slack_channel_data.rbs', line 76
def initialize: (url: String) -> void
|
Instance Attribute Details
#url ⇒ String
The URL of the incoming webhook for a Slack connection.
85 |
# File 'lib/knockapi/models/recipients/slack_channel_data.rb', line 85 required :url, String |
Instance Method Details
#to_hash ⇒ { url: String }
78 |
# File 'sig/knockapi/models/recipients/slack_channel_data.rbs', line 78
def to_hash: -> { url: String }
|