Class: Knockapi::Models::Tenant::Settings::Branding

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/tenant.rb,
sig/knockapi/models/tenant.rbs

Overview

See Also:

  • Knockapi::Models::Tenant::Settings#branding

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dark_icon_url: nil, dark_logo_url: nil, dark_primary_color: nil, dark_primary_color_contrast: nil, icon_url: nil, logo_url: nil, primary_color: nil, primary_color_contrast: nil) ⇒ Object

Some parameter documentations has been truncated, see Knockapi::Models::Tenant::Settings::Branding for more details.

The branding for the tenant.

Parameters:

  • dark_icon_url (String, nil) (defaults to: nil)

    The icon URL for the tenant in dark mode. Falls back to icon_url if unset.

  • dark_logo_url (String, nil) (defaults to: nil)

    The logo URL for the tenant in dark mode. Falls back to logo_url if unset.

  • dark_primary_color (String, nil) (defaults to: nil)

    The primary color for the tenant in dark mode, provided as a hex value. Defaults

  • dark_primary_color_contrast (String, nil) (defaults to: nil)

    The primary color contrast for the tenant in dark mode, provided as a hex value.

  • icon_url (String, nil) (defaults to: nil)

    The icon URL for the tenant. Must point to a valid image with an image MIME type

  • logo_url (String, nil) (defaults to: nil)

    The logo URL for the tenant. Must point to a valid image with an image MIME type

  • primary_color (String, nil) (defaults to: nil)

    The primary color for the tenant, provided as a hex value.

  • primary_color_contrast (String, nil) (defaults to: nil)

    The primary color contrast for the tenant, provided as a hex value.



# File 'lib/knockapi/models/tenant.rb', line 121

Instance Attribute Details

#dark_icon_urlString?

The icon URL for the tenant in dark mode. Falls back to icon_url if unset.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


73
# File 'lib/knockapi/models/tenant.rb', line 73

optional :dark_icon_url, String, nil?: true

#dark_logo_urlString?

The logo URL for the tenant in dark mode. Falls back to logo_url if unset.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


79
# File 'lib/knockapi/models/tenant.rb', line 79

optional :dark_logo_url, String, nil?: true

#dark_primary_colorString?

The primary color for the tenant in dark mode, provided as a hex value. Defaults to #FFFFFF.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


86
# File 'lib/knockapi/models/tenant.rb', line 86

optional :dark_primary_color, String, nil?: true

#dark_primary_color_contrastString?

The primary color contrast for the tenant in dark mode, provided as a hex value. Defaults to #000000.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


93
# File 'lib/knockapi/models/tenant.rb', line 93

optional :dark_primary_color_contrast, String, nil?: true

#icon_urlString?

The icon URL for the tenant. Must point to a valid image with an image MIME type.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


100
# File 'lib/knockapi/models/tenant.rb', line 100

optional :icon_url, String, nil?: true

#logo_urlString?

The logo URL for the tenant. Must point to a valid image with an image MIME type.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


107
# File 'lib/knockapi/models/tenant.rb', line 107

optional :logo_url, String, nil?: true

#primary_colorString?

The primary color for the tenant, provided as a hex value.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


113
# File 'lib/knockapi/models/tenant.rb', line 113

optional :primary_color, String, nil?: true

#primary_color_contrastString?

The primary color contrast for the tenant, provided as a hex value.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


119
# File 'lib/knockapi/models/tenant.rb', line 119

optional :primary_color_contrast, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


95
# File 'sig/knockapi/models/tenant.rbs', line 95

def to_hash: -> {