Class: Knockapi::Models::TenantSetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::TenantSetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/tenant_set_params.rb,
sig/knockapi/models/tenant_set_params.rbs
Overview
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#channel_data ⇒ Hash{Symbol=>Knockapi::Models::Recipients::PushChannelDataTokensOnly, Knockapi::Models::Recipients::PushChannelDataDevicesOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataTargetArnsOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataDevicesOnly, Knockapi::Models::Recipients::OneSignalChannelDataPlayerIDsOnly, Knockapi::Models::Recipients::SlackChannelData, Knockapi::Models::Recipients::MsTeamsChannelData, Knockapi::Models::Recipients::DiscordChannelData}?
A request to set channel data for a type of channel inline.
- #id ⇒ String
-
#name ⇒ String?
An optional name for the tenant.
-
#resolve_full_preference_settings ⇒ Boolean?
When true, merges environment-level default preferences into the tenant's
settings.preference_setfield before returning the response. -
#settings ⇒ Knockapi::Models::TenantSetParams::Settings?
The settings for the tenant.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
33 |
# File 'sig/knockapi/models/tenant_set_params.rbs', line 33
def initialize: (
|
Instance Attribute Details
#channel_data ⇒ Hash{Symbol=>Knockapi::Models::Recipients::PushChannelDataTokensOnly, Knockapi::Models::Recipients::PushChannelDataDevicesOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataTargetArnsOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataDevicesOnly, Knockapi::Models::Recipients::OneSignalChannelDataPlayerIDsOnly, Knockapi::Models::Recipients::SlackChannelData, Knockapi::Models::Recipients::MsTeamsChannelData, Knockapi::Models::Recipients::DiscordChannelData}?
A request to set channel data for a type of channel inline.
27 28 29 30 31 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 27 optional :channel_data, -> { Knockapi::Internal::Type::HashOf[union: Knockapi::Recipients::InlineChannelDataRequestItem] }, nil?: true |
#id ⇒ String
13 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 13 required :id, String |
#name ⇒ String?
An optional name for the tenant.
37 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 37 optional :name, String, nil?: true |
#resolve_full_preference_settings ⇒ Boolean?
When true, merges environment-level default preferences into the tenant's
settings.preference_set field before returning the response. Defaults to
false.
21 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 21 optional :resolve_full_preference_settings, Knockapi::Internal::Type::Boolean |
#settings ⇒ Knockapi::Models::TenantSetParams::Settings?
The settings for the tenant. Includes branding and preference set.
43 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 43 optional :settings, -> { Knockapi::TenantSetParams::Settings } |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/knockapi/models/tenant_set_params.rbs', line 42
def to_hash: -> {
|