Class: Knockapi::Models::TenantSetParams::Settings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::TenantSetParams::Settings
- Defined in:
- lib/knockapi/models/tenant_set_params.rb,
sig/knockapi/models/tenant_set_params.rbs
Defined Under Namespace
Classes: Branding
Instance Attribute Summary collapse
-
#branding ⇒ Knockapi::Models::TenantSetParams::Settings::Branding?
The branding for the tenant.
-
#preference_set ⇒ Knockapi::Models::Recipients::PreferenceSetRequest?
A request to set a preference set for a recipient.
Instance Method Summary collapse
-
#initialize(branding: nil, preference_set: nil) ⇒ Object
constructor
The settings for the tenant.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(branding: nil, preference_set: nil) ⇒ Object
The settings for the tenant. Includes branding and preference set.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 61 class Settings < Knockapi::Internal::Type::BaseModel # @!attribute branding # The branding for the tenant. # # @return [Knockapi::Models::TenantSetParams::Settings::Branding, nil] optional :branding, -> { Knockapi::TenantSetParams::Settings::Branding } # @!attribute preference_set # A request to set a preference set for a recipient. # # @return [Knockapi::Models::Recipients::PreferenceSetRequest, nil] optional :preference_set, -> { Knockapi::Recipients::PreferenceSetRequest }, nil?: true # @!method initialize(branding: nil, preference_set: nil) # The settings for the tenant. Includes branding and preference set. # # @param branding [Knockapi::Models::TenantSetParams::Settings::Branding] The branding for the tenant. # # @param preference_set [Knockapi::Models::Recipients::PreferenceSetRequest, nil] A request to set a preference set for a recipient. # @see Knockapi::Models::TenantSetParams::Settings#branding class Branding < Knockapi::Internal::Type::BaseModel # @!attribute icon_url # The icon URL for the tenant. Must point to a valid image with an image MIME # type. # # @return [String, nil] optional :icon_url, String, nil?: true # @!attribute logo_url # The logo URL for the tenant. Must point to a valid image with an image MIME # type. # # @return [String, nil] optional :logo_url, String, nil?: true # @!attribute primary_color # The primary color for the tenant, provided as a hex value. # # @return [String, nil] optional :primary_color, String, nil?: true # @!attribute primary_color_contrast # The primary color contrast for the tenant, provided as a hex value. # # @return [String, nil] optional :primary_color_contrast, String, nil?: true # @!method initialize(icon_url: nil, logo_url: nil, primary_color: nil, primary_color_contrast: nil) # Some parameter documentations has been truncated, see # {Knockapi::Models::TenantSetParams::Settings::Branding} for more details. # # The branding for the tenant. # # @param icon_url [String, nil] The icon URL for the tenant. Must point to a valid image with an image MIME type # # @param logo_url [String, nil] The logo URL for the tenant. Must point to a valid image with an image MIME type # # @param primary_color [String, nil] The primary color for the tenant, provided as a hex value. # # @param primary_color_contrast [String, nil] The primary color contrast for the tenant, provided as a hex value. end end |
Instance Attribute Details
#branding ⇒ Knockapi::Models::TenantSetParams::Settings::Branding?
The branding for the tenant.
66 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 66 optional :branding, -> { Knockapi::TenantSetParams::Settings::Branding } |
#preference_set ⇒ Knockapi::Models::Recipients::PreferenceSetRequest?
A request to set a preference set for a recipient.
72 |
# File 'lib/knockapi/models/tenant_set_params.rb', line 72 optional :preference_set, -> { Knockapi::Recipients::PreferenceSetRequest }, nil?: true |
Instance Method Details
#to_hash ⇒ {
71 |
# File 'sig/knockapi/models/tenant_set_params.rbs', line 71
def to_hash: -> {
|