Class: Knockapi::Models::TenantSetParams::Settings::Branding

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/tenant_set_params.rb,
sig/knockapi/models/tenant_set_params.rbs

Overview

See Also:

  • Knockapi::Models::TenantSetParams::Settings#branding

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(icon_url: nil, logo_url: nil, primary_color: nil, primary_color_contrast: nil) ⇒ Object

Some parameter documentations has been truncated, see Knockapi::Models::TenantSetParams::Settings::Branding for more details.

The branding for the tenant.

Parameters:

  • icon_url (String, nil) (defaults to: nil)

    The icon URL for the tenant. Must point to a valid image with an image MIME type

  • logo_url (String, nil) (defaults to: nil)

    The logo URL for the tenant. Must point to a valid image with an image MIME type

  • primary_color (String, nil) (defaults to: nil)

    The primary color for the tenant, provided as a hex value.

  • primary_color_contrast (String, nil) (defaults to: nil)

    The primary color contrast for the tenant, provided as a hex value.



# File 'lib/knockapi/models/tenant_set_params.rb', line 109

Instance Attribute Details

#icon_urlString?

The icon URL for the tenant. Must point to a valid image with an image MIME type.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


88
# File 'lib/knockapi/models/tenant_set_params.rb', line 88

optional :icon_url, String, nil?: true

#logo_urlString?

The logo URL for the tenant. Must point to a valid image with an image MIME type.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


95
# File 'lib/knockapi/models/tenant_set_params.rb', line 95

optional :logo_url, String, nil?: true

#primary_colorString?

The primary color for the tenant, provided as a hex value.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


101
# File 'lib/knockapi/models/tenant_set_params.rb', line 101

optional :primary_color, String, nil?: true

#primary_color_contrastString?

The primary color contrast for the tenant, provided as a hex value.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


107
# File 'lib/knockapi/models/tenant_set_params.rb', line 107

optional :primary_color_contrast, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


100
# File 'sig/knockapi/models/tenant_set_params.rbs', line 100

def to_hash: -> {