Class: Knockapi::Models::Users::BulkSetPreferencesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Users::BulkSetPreferencesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/users/bulk_set_preferences_params.rb,
sig/knockapi/models/users/bulk_set_preferences_params.rbs
Overview
Defined Under Namespace
Classes: Preferences
Instance Attribute Summary collapse
-
#preferences ⇒ Knockapi::Models::Users::BulkSetPreferencesParams::Preferences
A preference set to apply in a bulk operation.
-
#user_ids ⇒ Array<String>
A list of user IDs.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
19 |
# File 'sig/knockapi/models/users/bulk_set_preferences_params.rbs', line 19
def initialize: (
|
Instance Attribute Details
#preferences ⇒ Knockapi::Models::Users::BulkSetPreferencesParams::Preferences
A preference set to apply in a bulk operation. Always replaces existing preferences for the specified set.
16 |
# File 'lib/knockapi/models/users/bulk_set_preferences_params.rb', line 16 required :preferences, -> { Knockapi::Users::BulkSetPreferencesParams::Preferences } |
#user_ids ⇒ Array<String>
A list of user IDs.
22 |
# File 'lib/knockapi/models/users/bulk_set_preferences_params.rb', line 22 required :user_ids, Knockapi::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
25 |
# File 'sig/knockapi/models/users/bulk_set_preferences_params.rbs', line 25
def to_hash: -> {
|