Class: Knockapi::Models::Users::BulkSetPreferencesParams::Preferences::Workflow::PreferenceSetWorkflowCategorySettingObject

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/knockapi/models/users/bulk_set_preferences_params.rb,
sig/knockapi/models/users/bulk_set_preferences_params.rbs

Defined Under Namespace

Modules: Channel

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_types: nil, channels: nil, conditions: nil) ⇒ Object

The settings object for a workflow or category, where you can specify channel types or conditions.

Parameters:



# File 'lib/knockapi/models/users/bulk_set_preferences_params.rb', line 239

Instance Attribute Details

#channel_types ⇒ Knockapi::Models::Recipients::PreferenceSetChannelTypes?

Channel type preferences.

Parameters:

  • value (Knockapi::Recipients::PreferenceSetChannelTypes, nil)

Returns:



219
# File 'lib/knockapi/models/users/bulk_set_preferences_params.rb', line 219

optional :channel_types, -> { Knockapi::Recipients::PreferenceSetChannelTypes }, nil?: true

#channels ⇒ Hash{Symbol=>Boolean, Knockapi::Models::Recipients::PreferenceSetChannelSetting}?

Channel preferences.

Parameters:

  • value (::Hash[Symbol, Knockapi::Models::Users::BulkSetPreferencesParams::Preferences::Workflow::PreferenceSetWorkflowCategorySettingObject::channel], nil)

Returns:



225
226
227
228
229
230
231
# File 'lib/knockapi/models/users/bulk_set_preferences_params.rb', line 225

optional :channels,
-> do
  Knockapi::Internal::Type::HashOf[
    union: Knockapi::Users::BulkSetPreferencesParams::Preferences::Workflow::PreferenceSetWorkflowCategorySettingObject::Channel
  ]
end,
nil?: true

#conditions ⇒ Array<Knockapi::Models::Condition>?

A list of conditions to apply to a channel type.

Parameters:

Returns:



237
# File 'lib/knockapi/models/users/bulk_set_preferences_params.rb', line 237

optional :conditions, -> { Knockapi::Internal::Type::ArrayOf[Knockapi::Condition] }, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


165
# File 'sig/knockapi/models/users/bulk_set_preferences_params.rbs', line 165

def to_hash: -> {