Class: Knockapi::Models::Users::FeedListItemsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/knockapi/models/users/feed_list_items_params.rb,
sig/knockapi/models/users/feed_list_items_params.rbs

Overview

See Also:

  • Knockapi::Resources::Users::Feeds#list_items

Defined Under Namespace

Modules: Archived, Mode, Status Classes: InsertedAt

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Object

Parameters:

  • gt (String) (defaults to: nil)

    Limits the results to items inserted after the given date.

  • gte (String) (defaults to: nil)

    Limits the results to items inserted after or on the given date.

  • lt (String) (defaults to: nil)

    Limits the results to items inserted before the given date.

  • lte (String) (defaults to: nil)

    Limits the results to items inserted before or on the given date.



# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 112

Instance Attribute Details

#afterString?

The cursor to fetch entries after.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 25

optional :after, String

#archivedSymbol, ...

The archived status of the feed items.



31
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 31

optional :archived, enum: -> { Knockapi::Users::FeedListItemsParams::Archived }

#beforeString?

The cursor to fetch entries before.

Parameters:

  • (String)

Returns:

  • (String, nil)


37
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 37

optional :before, String

#excludeString?

Comma-separated list of field paths to exclude from the response. Use dot notation for nested fields (e.g., entries.archived_at). Limited to 3 levels deep.

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 45

optional :exclude, String

#has_tenantBoolean?

Whether the feed items have a tenant.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


51
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 51

optional :has_tenant, Knockapi::Internal::Type::Boolean

#idString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 19

required :id, String

#inserted_atKnockapi::Models::Users::FeedListItemsParams::InsertedAt?



56
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 56

optional :inserted_at, -> { Knockapi::Users::FeedListItemsParams::InsertedAt }

#localeString?

The locale to render the feed items in. Must be in the IETF 5646 format (e.g. en-US). When not provided, will default to the locale that the feed items were rendered in. Only available for enterprise plan customers using custom translations.

Parameters:

  • (String)

Returns:

  • (String, nil)


65
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 65

optional :locale, String

#modeSymbol, ...

The mode to render the feed items in. Can be compact or rich. Defaults to rich. When mode is compact, feed items will not have activities and total_activities fields; the data field will not include nested arrays and objects; and the actors field will only have up to one actor.



74
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 74

optional :mode, enum: -> { Knockapi::Users::FeedListItemsParams::Mode }

#page_sizeInteger?

The number of items per page (defaults to 50).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


80
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 80

optional :page_size, Integer

#sourceString?

The workflow key associated with the message in the feed.

Parameters:

  • (String)

Returns:

  • (String, nil)


86
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 86

optional :source, String

#statusSymbol, ...

The status of the feed items.



92
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 92

optional :status, enum: -> { Knockapi::Users::FeedListItemsParams::Status }

#tenantString?

The tenant associated with the feed items.

Parameters:

  • (String)

Returns:

  • (String, nil)


98
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 98

optional :tenant, String

#trigger_dataString?

The trigger data of the feed items (as a JSON string).

Parameters:

  • (String)

Returns:

  • (String, nil)


104
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 104

optional :trigger_data, String

#user_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 14

required :user_id, String

#workflow_categoriesArray<String>?

The workflow categories of the feed items.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


110
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 110

optional :workflow_categories, Knockapi::Internal::Type::ArrayOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 158

Instance Method Details

#to_hash{

Returns:

  • ({)


117
# File 'sig/knockapi/models/users/feed_list_items_params.rbs', line 117

def to_hash: -> {