Class: Knockapi::Models::Users::FeedListItemsParams::InsertedAt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/users/feed_list_items_params.rb,
sig/knockapi/models/users/feed_list_items_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



168
# File 'sig/knockapi/models/users/feed_list_items_params.rbs', line 168

def initialize: (

Instance Attribute Details

#gtString?

Limits the results to items inserted after the given date.

Parameters:

  • (String)

Returns:

  • (String, nil)


167
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 167

optional :gt, String

#gteString?

Limits the results to items inserted after or on the given date.

Parameters:

  • (String)

Returns:

  • (String, nil)


173
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 173

optional :gte, String

#ltString?

Limits the results to items inserted before the given date.

Parameters:

  • (String)

Returns:

  • (String, nil)


179
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 179

optional :lt, String

#lteString?

Limits the results to items inserted before or on the given date.

Parameters:

  • (String)

Returns:

  • (String, nil)


185
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 185

optional :lte, String

Instance Method Details

#to_hash{ gt: String, gte: String, lt: String, lte: String }

Returns:

  • ({ gt: String, gte: String, lt: String, lte: String })


175
# File 'sig/knockapi/models/users/feed_list_items_params.rbs', line 175

def to_hash: -> { gt: String, gte: String, lt: String, lte: String }