Module: Knockapi::Models::Users::FeedListItemsParams::Mode

Extended by:
Internal::Type::Enum
Defined in:
lib/knockapi/models/users/feed_list_items_params.rb,
sig/knockapi/models/users/feed_list_items_params.rbs

Overview

The mode to render the feed items in. Can be compact or rich. Defaults to rich. When mode is compact, feed items will not have activities and total_activities fields; the data field will not include nested arrays and objects; and the actors field will only have up to one actor.

Constant Summary collapse

COMPACT =

Returns:

  • (:compact)
:compact
RICH =

Returns:

  • (:rich)
:rich

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Knockapi::Models::Users::FeedListItemsParams::mode]

Returns:

  • (::Array[Knockapi::Models::Users::FeedListItemsParams::mode])


186
# File 'sig/knockapi/models/users/feed_list_items_params.rbs', line 186

def self?.values: -> ::Array[Knockapi::Models::Users::FeedListItemsParams::mode]