Class: Knockapi::Models::Users::GuideGetChannelResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/users/guide_get_channel_response.rb,
sig/knockapi/models/users/guide_get_channel_response.rbs

Overview

See Also:

  • Knockapi::Resources::Users::Guides#get_channel

Defined Under Namespace

Classes: Entry, GuideGroup, IneligibleGuide

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(_typename: nil, display_interval: nil, display_sequence: nil, inserted_at: nil, key: nil, updated_at: nil) ⇒ Object

Parameters:

  • _typename (String) (defaults to: nil)
  • display_interval (Integer) (defaults to: nil)
  • display_sequence (Array<String>) (defaults to: nil)
  • inserted_at (Time) (defaults to: nil)
  • key (String) (defaults to: nil)
  • updated_at (Time) (defaults to: nil)


# File 'lib/knockapi/models/users/guide_get_channel_response.rb', line 295

Instance Attribute Details

#entriesArray<Knockapi::Models::Users::GuideGetChannelResponse::Entry>

A list of guides.



12
13
# File 'lib/knockapi/models/users/guide_get_channel_response.rb', line 12

required :entries,
-> { Knockapi::Internal::Type::ArrayOf[Knockapi::Models::Users::GuideGetChannelResponse::Entry] }

#guide_group_display_logsHash{Symbol=>Time}

A map of guide group keys to their last display timestamps.

Parameters:

  • value (::Hash[Symbol, Time])

Returns:

  • (Hash{Symbol=>Time})


19
# File 'lib/knockapi/models/users/guide_get_channel_response.rb', line 19

required :guide_group_display_logs, Knockapi::Internal::Type::HashOf[Time]

#guide_groupsArray<Knockapi::Models::Users::GuideGetChannelResponse::GuideGroup>

A list of guide groups with their display sequences and intervals.



25
26
# File 'lib/knockapi/models/users/guide_get_channel_response.rb', line 25

required :guide_groups,
-> { Knockapi::Internal::Type::ArrayOf[Knockapi::Models::Users::GuideGetChannelResponse::GuideGroup] }

#ineligible_guidesArray<Knockapi::Models::Users::GuideGetChannelResponse::IneligibleGuide>

Markers for guides the user is not eligible to see.



32
33
# File 'lib/knockapi/models/users/guide_get_channel_response.rb', line 32

required :ineligible_guides,
-> { Knockapi::Internal::Type::ArrayOf[Knockapi::Models::Users::GuideGetChannelResponse::IneligibleGuide] }

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/knockapi/models/users/guide_get_channel_response.rbs', line 28

def to_hash: -> {