Class: Knockapi::Models::Users::GuideInteractedRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Users::GuideInteractedRequest
- Defined in:
- lib/knockapi/models/users/guide_interacted_request.rb,
sig/knockapi/models/users/guide_interacted_request.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The unique identifier for the channel.
-
#guide_id ⇒ String
The unique identifier for the guide.
-
#guide_key ⇒ String
The key of the guide.
-
#guide_step_ref ⇒ String
The step reference of the guide.
-
#metadata ⇒ Hash{Symbol=>Object}?
Metadata about the interaction.
-
#tenant ⇒ String?
The tenant ID of the guide.
Instance Method Summary collapse
-
#initialize(channel_id:, guide_id:, guide_key:, guide_step_ref:, metadata: nil, tenant: nil) ⇒ Object
constructor
A request to mark a guide as interacted with.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(channel_id:, guide_id:, guide_key:, guide_step_ref:, metadata: nil, tenant: nil) ⇒ Object
A request to mark a guide as interacted with.
|
|
# File 'lib/knockapi/models/users/guide_interacted_request.rb', line 43
|
Instance Attribute Details
#channel_id ⇒ String
The unique identifier for the channel.
11 |
# File 'lib/knockapi/models/users/guide_interacted_request.rb', line 11 required :channel_id, String |
#guide_id ⇒ String
The unique identifier for the guide.
17 |
# File 'lib/knockapi/models/users/guide_interacted_request.rb', line 17 required :guide_id, String |
#guide_key ⇒ String
The key of the guide.
23 |
# File 'lib/knockapi/models/users/guide_interacted_request.rb', line 23 required :guide_key, String |
#guide_step_ref ⇒ String
The step reference of the guide.
29 |
# File 'lib/knockapi/models/users/guide_interacted_request.rb', line 29 required :guide_step_ref, String |
#metadata ⇒ Hash{Symbol=>Object}?
Metadata about the interaction.
35 |
# File 'lib/knockapi/models/users/guide_interacted_request.rb', line 35 optional :metadata, Knockapi::Internal::Type::HashOf[Knockapi::Internal::Type::Unknown] |
#tenant ⇒ String?
The tenant ID of the guide.
41 |
# File 'lib/knockapi/models/users/guide_interacted_request.rb', line 41 optional :tenant, String |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/knockapi/models/users/guide_interacted_request.rbs', line 40
def to_hash: -> {
|