Class: Knockapi::Models::Users::PreferenceCenterBrandingConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Users::PreferenceCenterBrandingConfig
- Defined in:
- lib/knockapi/models/users/preference_center_branding_config.rb,
sig/knockapi/models/users/preference_center_branding_config.rbs
Direct Known Subclasses
Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Branding
Instance Attribute Summary collapse
-
#icon_url ⇒ String?
The icon URL for the preference center.
-
#logo_url ⇒ String?
The logo URL for the preference center.
-
#primary_color ⇒ String?
The primary color for the preference center, provided as a hex value.
-
#primary_color_contrast ⇒ String?
The primary color contrast for the preference center, provided as a hex value.
Instance Method Summary collapse
-
#initialize(icon_url: nil, logo_url: nil, primary_color: nil, primary_color_contrast: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PreferenceCenterBrandingConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(icon_url: nil, logo_url: nil, primary_color: nil, primary_color_contrast: nil) ⇒ Object
Some parameter documentations has been truncated, see Knockapi::Models::Users::PreferenceCenterBrandingConfig for more details.
The branding for the preference center, sourced from public environment variables.
|
|
# File 'lib/knockapi/models/users/preference_center_branding_config.rb', line 33
|
Instance Attribute Details
#icon_url ⇒ String?
The icon URL for the preference center. Must point to a valid image with an image MIME type.
12 |
# File 'lib/knockapi/models/users/preference_center_branding_config.rb', line 12 optional :icon_url, String, nil?: true |
#logo_url ⇒ String?
The logo URL for the preference center. Must point to a valid image with an image MIME type.
19 |
# File 'lib/knockapi/models/users/preference_center_branding_config.rb', line 19 optional :logo_url, String, nil?: true |
#primary_color ⇒ String?
The primary color for the preference center, provided as a hex value.
25 |
# File 'lib/knockapi/models/users/preference_center_branding_config.rb', line 25 optional :primary_color, String, nil?: true |
#primary_color_contrast ⇒ String?
The primary color contrast for the preference center, provided as a hex value.
31 |
# File 'lib/knockapi/models/users/preference_center_branding_config.rb', line 31 optional :primary_color_contrast, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/knockapi/models/users/preference_center_branding_config.rbs', line 28
def to_hash: -> {
|