Class: Knockapi::Models::Users::PreferenceCenterGenerateSignedURLResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/users/preference_center_generate_signed_url_response.rb,
sig/knockapi/models/users/preference_center_generate_signed_url_response.rbs

Overview

See Also:

  • Knockapi::Resources::Users::PreferenceCenter#generate_signed_url

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, url:) ⇒ PreferenceCenterGenerateSignedURLResponse

Some parameter documentations has been truncated, see Knockapi::Models::Users::PreferenceCenterGenerateSignedURLResponse for more details.

A signed preference center URL and token for a user.

Parameters:

  • token (String) —

    The signed JWT token for the preference center, usable as the /p/{token} path

  • url (String) —

    The full URL to the preference center for the user.

  • token: (String)
  • url: (String)


# File 'lib/knockapi/models/users/preference_center_generate_signed_url_response.rb', line 21

Instance Attribute Details

#token ⇒ String

The signed JWT token for the preference center, usable as the /p/{token} path segment.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/knockapi/models/users/preference_center_generate_signed_url_response.rb', line 13

required :token, String

#url ⇒ String

The full URL to the preference center for the user.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/knockapi/models/users/preference_center_generate_signed_url_response.rb', line 19

required :url, String

Instance Method Details

#to_hash ⇒ { token: String, url: String }

Returns:

  • ({ token: String, url: String })


14
# File 'sig/knockapi/models/users/preference_center_generate_signed_url_response.rbs', line 14

def to_hash: -> { token: String, url: String }