Class: Knockapi::Models::Users::PreferenceCenterGetConfigResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/users/preference_center_get_config_response.rb,
sig/knockapi/models/users/preference_center_get_config_response.rbs

Overview

See Also:

  • Knockapi::Resources::Users::PreferenceCenter#get_config

Defined Under Namespace

Classes: Branding, Config

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dark: nil) ⇒ Object

Some parameter documentations has been truncated, see Branding for more details.

The branding for the preference center, sourced from public environment variables.

Parameters:



# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 46

Instance Attribute Details

#account_name ⇒ String?

The name of the account that the preference center is associated with.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


12
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 12

required :account_name, String, nil?: true

#branding ⇒ Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Branding

The branding for the preference center, sourced from public environment variables.



19
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 19

required :branding, -> { Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Branding }

#config ⇒ Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Config

The preference center configuration data containing the rows to display.



25
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 25

required :config, -> { Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Config }

#enabled ⇒ Boolean

Whether the preference center is enabled for this environment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


31
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 31

required :enabled, Knockapi::Internal::Type::Boolean

#knock_branding_required ⇒ Boolean?

Whether Knock branding is required in the preference center.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


44
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 44

optional :knock_branding_required, Knockapi::Internal::Type::Boolean

#user_email ⇒ String?

A display label for the user that the preference center is associated with, resolved as email, then user id.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 38

required :user_email, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


38
# File 'sig/knockapi/models/users/preference_center_get_config_response.rbs', line 38

def to_hash: -> {