Class: Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Branding
- Inherits:
-
Knockapi::Models::Users::PreferenceCenterBrandingConfig
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Users::PreferenceCenterBrandingConfig
- Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Branding
- Defined in:
- lib/knockapi/models/users/preference_center_get_config_response.rb,
sig/knockapi/models/users/preference_center_get_config_response.rbs
Overview
Instance Attribute Summary collapse
-
#dark ⇒ Knockapi::Models::Users::PreferenceCenterBrandingConfig?
The branding for the preference center, sourced from public environment variables.
Attributes inherited from Knockapi::Models::Users::PreferenceCenterBrandingConfig
#icon_url, #logo_url, #primary_color, #primary_color_contrast
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
57 |
# File 'sig/knockapi/models/users/preference_center_get_config_response.rbs', line 57
def initialize: (
|
Instance Attribute Details
#dark ⇒ Knockapi::Models::Users::PreferenceCenterBrandingConfig?
The branding for the preference center, sourced from public environment variables.
72 |
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 72 optional :dark, -> { Knockapi::Users::PreferenceCenterBrandingConfig } |
Instance Method Details
#to_hash ⇒ {
61 |
# File 'sig/knockapi/models/users/preference_center_get_config_response.rbs', line 61
def to_hash: -> {
|