Class: Knockapi::Models::WorkflowCancelParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::WorkflowCancelParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/workflow_cancel_params.rb,
sig/knockapi/models/workflow_cancel_params.rbs
Overview
Instance Attribute Summary collapse
-
#cancellation_key ⇒ String
A key that is used to reference a specific workflow trigger request when issuing a workflow cancellation request.
- #key ⇒ String
-
#recipients ⇒ Array<String, Knockapi::Models::RecipientReference::ObjectReference>?
A list of recipients to cancel the notification for.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(key:, cancellation_key:, recipients: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WorkflowCancelParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key:, cancellation_key:, recipients: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Knockapi::Models::WorkflowCancelParams for more details.
|
|
# File 'lib/knockapi/models/workflow_cancel_params.rb', line 34
|
Instance Attribute Details
#cancellation_key ⇒ String
A key that is used to reference a specific workflow trigger request when issuing a workflow cancellation request. Must be provided while triggering a workflow in order to enable subsequent cancellation. Should be unique across trigger requests to avoid unintentional cancellations.
23 |
# File 'lib/knockapi/models/workflow_cancel_params.rb', line 23 required :cancellation_key, String |
#key ⇒ String
13 |
# File 'lib/knockapi/models/workflow_cancel_params.rb', line 13 required :key, String |
#recipients ⇒ Array<String, Knockapi::Models::RecipientReference::ObjectReference>?
A list of recipients to cancel the notification for. If omitted, cancels for all recipients associated with the cancellation key.
30 31 32 |
# File 'lib/knockapi/models/workflow_cancel_params.rb', line 30 optional :recipients, -> { Knockapi::Internal::Type::ArrayOf[union: Knockapi::RecipientReference] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/knockapi/models/workflow_cancel_params.rbs', line 28
def to_hash: -> {
|