Class: Knockapi::Models::WorkflowRecipientRun::TriggerSource

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/workflow_recipient_run.rb,
sig/knockapi/models/workflow_recipient_run.rbs

Overview

See Also:

  • Knockapi::Models::WorkflowRecipientRun#trigger_source

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, audience_key: nil, cancellation_key: nil, schedule_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Knockapi::Models::WorkflowRecipientRun::TriggerSource for more details.

Describes how the workflow was triggered.

Parameters:

  • type (Symbol, Knockapi::Models::WorkflowRecipientRun::TriggerSource::Type)

    The type of trigger source. One of api, audience, schedule, broadcast, `

  • audience_key (String, nil) (defaults to: nil)

    The key of the audience that triggered the workflow.

  • cancellation_key (String, nil) (defaults to: nil)

    The cancellation key provided when the workflow was triggered via the API.

  • schedule_id (String, nil) (defaults to: nil)

    The ID of the schedule that triggered the workflow.



# File 'lib/knockapi/models/workflow_recipient_run.rb', line 158

Instance Attribute Details

#audience_keyString?

The key of the audience that triggered the workflow.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


144
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 144

optional :audience_key, String, nil?: true

#cancellation_keyString?

The cancellation key provided when the workflow was triggered via the API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


150
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 150

optional :cancellation_key, String, nil?: true

#schedule_idString?

The ID of the schedule that triggered the workflow.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


156
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 156

optional :schedule_id, String, nil?: true

#typeSymbol, Knockapi::Models::WorkflowRecipientRun::TriggerSource::Type

The type of trigger source. One of api, audience, schedule, broadcast, workflow_step, integration, or rehearsal.

Parameters:

  • value (Knockapi::Models::WorkflowRecipientRun::TriggerSource::type_)

Returns:



138
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 138

required :type, enum: -> { Knockapi::WorkflowRecipientRun::TriggerSource::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


114
# File 'sig/knockapi/models/workflow_recipient_run.rbs', line 114

def to_hash: -> {