Class: Knockapi::Models::WorkflowRecipientRunDetail
- Inherits:
-
WorkflowRecipientRun
- Object
- Internal::Type::BaseModel
- WorkflowRecipientRun
- Knockapi::Models::WorkflowRecipientRunDetail
- Defined in:
- lib/knockapi/models/workflow_recipient_run_detail.rb,
sig/knockapi/models/workflow_recipient_run_detail.rbs
Overview
Instance Attribute Summary collapse
-
#events ⇒ Array<Knockapi::Models::WorkflowRecipientRunEvent>
A list of events that occurred during the workflow recipient run.
Attributes inherited from WorkflowRecipientRun
#_typename, #actor, #error_count, #id, #inserted_at, #recipient, #status, #tenant, #trigger_source, #updated_at, #workflow, #workflow_run_id
Instance Method Summary collapse
-
#initialize(events:) ⇒ Object
constructor
A single workflow recipient run with its events.
- #to_hash ⇒ { events: ::Array[Knockapi::WorkflowRecipientRunEvent] }
Methods inherited from WorkflowRecipientRun
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(events:) ⇒ Object
A single workflow recipient run with its events.
|
|
# File 'lib/knockapi/models/workflow_recipient_run_detail.rb', line 13
|
Instance Attribute Details
#events ⇒ Array<Knockapi::Models::WorkflowRecipientRunEvent>
A list of events that occurred during the workflow recipient run.
11 |
# File 'lib/knockapi/models/workflow_recipient_run_detail.rb', line 11 required :events, -> { Knockapi::Internal::Type::ArrayOf[Knockapi::WorkflowRecipientRunEvent] } |
Instance Method Details
#to_hash ⇒ { events: ::Array[Knockapi::WorkflowRecipientRunEvent] }
17 |
# File 'sig/knockapi/models/workflow_recipient_run_detail.rbs', line 17
def to_hash: -> { events: ::Array[Knockapi::WorkflowRecipientRunEvent] }
|