Class: Knockapi::Models::WorkflowRecipientRunEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::WorkflowRecipientRunEvent
- Defined in:
- lib/knockapi/models/workflow_recipient_run_event.rb,
sig/knockapi/models/workflow_recipient_run_event.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#_typename ⇒ String
The typename of the schema.
-
#attempt ⇒ Integer?
The attempt number of the workflow recipient run event.
-
#data ⇒ Hash{Symbol=>Object}?
Event-specific data associated with the event.
-
#event ⇒ String
The type of event that occurred.
-
#id ⇒ String
The unique identifier for the event.
-
#inserted_at ⇒ Time
Timestamp when the resource was created.
-
#status ⇒ Symbol, Knockapi::Models::WorkflowRecipientRunEvent::Status
Whether the event represents a successful or error state.
-
#step_ref ⇒ String?
The reference of the workflow step associated with this event.
-
#step_type ⇒ String?
The type of workflow step associated with this event.
Instance Method Summary collapse
-
#initialize(id:, _typename:, event:, inserted_at:, status:, attempt: nil, data: nil, step_ref: nil, step_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WorkflowRecipientRunEvent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, _typename:, event:, inserted_at:, status:, attempt: nil, data: nil, step_ref: nil, step_type: nil) ⇒ Object
Some parameter documentations has been truncated, see Knockapi::Models::WorkflowRecipientRunEvent for more details.
An event that occurred during a workflow recipient run.
|
|
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 61
|
Instance Attribute Details
#_typename ⇒ String
The typename of the schema.
16 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 16 required :_typename, String, api_name: :__typename |
#attempt ⇒ Integer?
The attempt number of the workflow recipient run event. Increments for each retry.
41 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 41 optional :attempt, Integer |
#data ⇒ Hash{Symbol=>Object}?
Event-specific data associated with the event.
47 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 47 optional :data, Knockapi::Internal::Type::HashOf[Knockapi::Internal::Type::Unknown], nil?: true |
#event ⇒ String
The type of event that occurred.
22 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 22 required :event, String |
#id ⇒ String
The unique identifier for the event.
10 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 10 required :id, String |
#inserted_at ⇒ Time
Timestamp when the resource was created.
28 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 28 required :inserted_at, Time |
#status ⇒ Symbol, Knockapi::Models::WorkflowRecipientRunEvent::Status
Whether the event represents a successful or error state.
34 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 34 required :status, enum: -> { Knockapi::WorkflowRecipientRunEvent::Status } |
#step_ref ⇒ String?
The reference of the workflow step associated with this event.
53 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 53 optional :step_ref, String, nil?: true |
#step_type ⇒ String?
The type of workflow step associated with this event.
59 |
# File 'lib/knockapi/models/workflow_recipient_run_event.rb', line 59 optional :step_type, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/knockapi/models/workflow_recipient_run_event.rbs', line 49
def to_hash: -> {
|