Class: Knockapi::Models::WorkflowRecipientRunListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/knockapi/models/workflow_recipient_run_list_params.rb,
sig/knockapi/models/workflow_recipient_run_list_params.rbs

Overview

See Also:

  • Knockapi::Resources::WorkflowRecipientRuns#list

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



66
# File 'sig/knockapi/models/workflow_recipient_run_list_params.rbs', line 66

def initialize: (

Instance Attribute Details

#afterString?

The cursor to fetch entries after.

Parameters:

  • (String)

Returns:

  • (String, nil)


14
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 14

optional :after, String

#beforeString?

The cursor to fetch entries before.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 20

optional :before, String

#ending_atTime?

Limits the results to workflow recipient runs started before the given date.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


26
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 26

optional :ending_at, Time

#has_errorsBoolean?

Limits the results to workflow recipient runs that have errors.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


32
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 32

optional :has_errors, Knockapi::Internal::Type::Boolean

#page_sizeInteger?

The number of items per page (defaults to 50).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


38
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 38

optional :page_size, Integer

#recipientString, ...

Limits the results to workflow recipient runs for the given recipient. Accepts a user ID string or an object reference with id and collection.



45
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 45

optional :recipient, union: -> { Knockapi::RecipientReference }

#starting_atTime?

Limits the results to workflow recipient runs started after the given date.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


51
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 51

optional :starting_at, Time

#statusArray<Symbol, Knockapi::Models::WorkflowRecipientRunListParams::Status>?

Limits the results to workflow recipient runs with the given status.



57
58
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 57

optional :status,
-> { Knockapi::Internal::Type::ArrayOf[enum: Knockapi::WorkflowRecipientRunListParams::Status] }

#tenantString?

Limits the results to workflow recipient runs for the given tenant.

Parameters:

  • (String)

Returns:

  • (String, nil)


64
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 64

optional :tenant, String

#workflowString?

Limits the results to workflow recipient runs for the given workflow key.

Parameters:

  • (String)

Returns:

  • (String, nil)


70
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 70

optional :workflow, String

Instance Method Details

#to_hash{

Returns:

  • ({)


80
# File 'sig/knockapi/models/workflow_recipient_run_list_params.rbs', line 80

def to_hash: -> {