Module: Knockapi::Models::WorkflowRecipientRunListParams::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/knockapi/models/workflow_recipient_run_list_params.rb,
sig/knockapi/models/workflow_recipient_run_list_params.rbs

Constant Summary collapse

QUEUED =

Returns:

  • (:queued)
:queued
PROCESSING =

Returns:

  • (:processing)
:processing
PAUSED =

Returns:

  • (:paused)
:paused
COMPLETED =

Returns:

  • (:completed)
:completed
CANCELLED =

Returns:

  • (:cancelled)
:cancelled

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 107

Instance Method Details

#initialize(after: nil, before: nil, ending_at: nil, has_errors: nil, page_size: nil, recipient: nil, starting_at: nil, status: nil, tenant: nil, workflow: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Knockapi::Models::WorkflowRecipientRunListParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    The cursor to fetch entries after.

  • before (String) (defaults to: nil)

    The cursor to fetch entries before.

  • ending_at (Time) (defaults to: nil)

    Limits the results to workflow recipient runs started before the given date.

  • has_errors (Boolean) (defaults to: nil)

    Limits the results to workflow recipient runs that have errors.

  • page_size (Integer) (defaults to: nil)

    The number of items per page (defaults to 50).

  • recipient (String, Knockapi::Models::RecipientReference::ObjectReference) (defaults to: nil)

    Limits the results to workflow recipient runs for the given recipient. Accepts a

  • starting_at (Time) (defaults to: nil)

    Limits the results to workflow recipient runs started after the given date.

  • status (Array<Symbol, Knockapi::Models::WorkflowRecipientRunListParams::Status>) (defaults to: nil)

    Limits the results to workflow recipient runs with the given status.

  • tenant (String) (defaults to: nil)

    Limits the results to workflow recipient runs for the given tenant.

  • workflow (String) (defaults to: nil)

    Limits the results to workflow recipient runs for the given workflow key.

  • request_options (Knockapi::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 98

module Status
  extend Knockapi::Internal::Type::Enum

  QUEUED = :queued
  PROCESSING = :processing
  PAUSED = :paused
  COMPLETED = :completed
  CANCELLED = :cancelled

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Knockapi::Models::WorkflowRecipientRunListParams::status]

Returns:

  • (::Array[Knockapi::Models::WorkflowRecipientRunListParams::status])


105
# File 'sig/knockapi/models/workflow_recipient_run_list_params.rbs', line 105

def self?.values: -> ::Array[Knockapi::Models::WorkflowRecipientRunListParams::status]