Class: Knockapi::Models::WorkflowTriggerParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/knockapi/models/workflow_trigger_params.rb,
sig/knockapi/models/workflow_trigger_params.rbs

Overview

See Also:

  • Knockapi::Resources::Workflows#trigger

Defined Under Namespace

Classes: Settings

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



33
# File 'sig/knockapi/models/workflow_trigger_params.rbs', line 33

def initialize: (

Instance Attribute Details

#actorString, ...

Specifies a recipient in a request. This can either be a user identifier (string), an inline user request (object), or an inline object request, which is determined by the presence of a collection property.

Parameters:

  • value (Knockapi::Models::recipient_request, nil)

Returns:



28
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 28

optional :actor, union: -> { Knockapi::RecipientRequest }, nil?: true

#cancellation_keyString?

A key that is used to reference a specific workflow trigger request when issuing a workflow cancellation request. Must be provided while triggering a workflow in order to enable subsequent cancellation. Should be unique across trigger requests to avoid unintentional cancellations.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 38

optional :cancellation_key, String, nil?: true

#dataHash{Symbol=>Object}?

An optional map of data to pass into the workflow execution. There is a 10MB limit on the size of the full data payload. Any individual string value greater than 1024 bytes in length will be truncated in your logs.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:



47
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 47

optional :data, Knockapi::Internal::Type::HashOf[Knockapi::Internal::Type::Unknown], nil?: true

#keyString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 13

required :key, String

#recipientsArray<String, Knockapi::Models::InlineIdentifyUserRequest, Knockapi::Models::InlineObjectRequest>

The recipients to trigger the workflow for. Can inline identify users, objects, or use a list of user IDs. Limited to 1,000 recipients.

Parameters:

  • value (::Array[Knockapi::Models::recipient_request])

Returns:



20
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 20

required :recipients, -> { Knockapi::Internal::Type::ArrayOf[union: Knockapi::RecipientRequest] }

#settingsKnockapi::Models::WorkflowTriggerParams::Settings?

Optional settings that control how this workflow trigger is executed.

Parameters:

  • value (Knockapi::WorkflowTriggerParams::Settings, nil)

Returns:



53
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 53

optional :settings, -> { Knockapi::WorkflowTriggerParams::Settings }, nil?: true

#tenantString, ...

An request to set a tenant inline.

Parameters:

  • value (Knockapi::Models::inline_tenant_request, nil)

Returns:



59
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 59

optional :tenant, union: -> { Knockapi::InlineTenantRequest }, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/knockapi/models/workflow_trigger_params.rbs', line 44

def to_hash: -> {