Class: Knockapi::Models::WorkflowTriggerParams::Settings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/workflow_trigger_params.rb,
sig/knockapi/models/workflow_trigger_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(sandbox_mode: nil, skip_delay: nil) ⇒ Settings

Some parameter documentations has been truncated, see Knockapi::Models::WorkflowTriggerParams::Settings for more details.

Optional settings that control how this workflow trigger is executed.

Parameters:

  • sandbox_mode (Boolean, nil) (defaults to: nil)

    When set to true, overrides the sandbox mode for all channels in this workflow r

  • skip_delay (Boolean, nil) (defaults to: nil)

    When set to true, skips all delay steps in the workflow for this trigger request

  • sandbox_mode: (Boolean, nil) (defaults to: nil)
  • skip_delay: (Boolean, nil) (defaults to: nil)


81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 81

class Settings < Knockapi::Internal::Type::BaseModel
  # @!attribute sandbox_mode
  #   When set to true, overrides the sandbox mode for all channels in this workflow
  #   run, messages are not delivered to the underlying providers. If false or not
  #   set, the workflow delivers messages normally.
  #
  #   @return [Boolean, nil]
  optional :sandbox_mode, Knockapi::Internal::Type::Boolean, nil?: true

  # @!attribute skip_delay
  #   When set to true, skips all delay steps in the workflow for this trigger
  #   request. If false or not set, delay steps execute normally.
  #
  #   @return [Boolean, nil]
  optional :skip_delay, Knockapi::Internal::Type::Boolean, nil?: true

  # @!method initialize(sandbox_mode: nil, skip_delay: nil)
  #   Some parameter documentations has been truncated, see
  #   {Knockapi::Models::WorkflowTriggerParams::Settings} for more details.
  #
  #   Optional settings that control how this workflow trigger is executed.
  #
  #   @param sandbox_mode [Boolean, nil] When set to true, overrides the sandbox mode for all channels in this workflow r
  #
  #   @param skip_delay [Boolean, nil] When set to true, skips all delay steps in the workflow for this trigger request
end

Instance Attribute Details

#sandbox_modeBoolean?

When set to true, overrides the sandbox mode for all channels in this workflow run, messages are not delivered to the underlying providers. If false or not set, the workflow delivers messages normally.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


88
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 88

optional :sandbox_mode, Knockapi::Internal::Type::Boolean, nil?: true

#skip_delayBoolean?

When set to true, skips all delay steps in the workflow for this trigger request. If false or not set, delay steps execute normally.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


95
# File 'lib/knockapi/models/workflow_trigger_params.rb', line 95

optional :skip_delay, Knockapi::Internal::Type::Boolean, nil?: true

Instance Method Details

#to_hash{ sandbox_mode: bool?, skip_delay: bool? }

Returns:

  • ({ sandbox_mode: bool?, skip_delay: bool? })


64
# File 'sig/knockapi/models/workflow_trigger_params.rbs', line 64

def to_hash: -> { sandbox_mode: bool?, skip_delay: bool? }