Class: Knockapi::Models::WorkflowTriggerResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/knockapi/models/workflow_trigger_response.rb,
sig/knockapi/models/workflow_trigger_response.rbs

Overview

See Also:

  • Knockapi::Resources::Workflows#trigger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workflow_run_id:) ⇒ WorkflowTriggerResponse

Some parameter documentations has been truncated, see Knockapi::Models::WorkflowTriggerResponse for more details.

The response from triggering a workflow.

Parameters:

  • workflow_run_id (String)

    This value allows you to track individual messages associated with this trigger

  • workflow_run_id: (String)


# File 'lib/knockapi/models/workflow_trigger_response.rb', line 14

Instance Attribute Details

#workflow_run_idString

This value allows you to track individual messages associated with this trigger request.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/knockapi/models/workflow_trigger_response.rb', line 12

required :workflow_run_id, String

Instance Method Details

#to_hash{ workflow_run_id: String }

Returns:

  • ({ workflow_run_id: String })


10
# File 'sig/knockapi/models/workflow_trigger_response.rbs', line 10

def to_hash: -> { workflow_run_id: String }