Class: Knockapi::Resources::Providers

Inherits:
Object
  • Object
show all
Defined in:
lib/knockapi/resources/providers.rb,
lib/knockapi/resources/providers/slack.rb,
lib/knockapi/resources/providers/ms_teams.rb,
sig/knockapi/resources/providers.rbs,
sig/knockapi/resources/providers/slack.rbs,
sig/knockapi/resources/providers/ms_teams.rbs

Defined Under Namespace

Classes: MsTeams, Slack

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Providers

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Providers.

Parameters:



19
20
21
22
23
# File 'lib/knockapi/resources/providers.rb', line 19

def initialize(client:)
  @client = client
  @slack = Knockapi::Resources::Providers::Slack.new(client: client)
  @ms_teams = Knockapi::Resources::Providers::MsTeams.new(client: client)
end

Instance Attribute Details

#ms_teamsKnockapi::Resources::Providers::MsTeams (readonly)

A provider represents a third-party service that Knock integrates with and is configured via a channel.



14
15
16
# File 'lib/knockapi/resources/providers.rb', line 14

def ms_teams
  @ms_teams
end

#slackKnockapi::Resources::Providers::Slack (readonly)

A provider represents a third-party service that Knock integrates with and is configured via a channel.



9
10
11
# File 'lib/knockapi/resources/providers.rb', line 9

def slack
  @slack
end