Class: Knockapi::Models::Channels::BulkUpdateMessageStatusParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Channels::BulkUpdateMessageStatusParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/channels/bulk_update_message_status_params.rb,
sig/knockapi/models/channels/bulk_update_message_status_params.rbs
Overview
Defined Under Namespace
Modules: Action, Archived, DeliveryStatus, EngagementStatus
Instance Attribute Summary collapse
- #action ⇒ Symbol, Knockapi::Models::Channels::BulkUpdateMessageStatusParams::Action
-
#archived ⇒ Symbol, ...
Limits the results to messages with the given archived status.
- #channel_id ⇒ String
-
#delivery_status ⇒ Symbol, ...
Limits the results to messages with the given delivery status.
-
#engagement_status ⇒ Symbol, ...
Limits the results to messages with the given engagement status.
-
#has_tenant ⇒ Boolean?
Limits the results to messages that have a tenant or not.
-
#newer_than ⇒ Time?
Limits the results to messages inserted after the given date.
-
#older_than ⇒ Time?
Limits the results to messages inserted before the given date.
-
#recipient_ids ⇒ Array<String>?
Limits the results to messages with the given recipient IDs.
-
#tenants ⇒ Array<String>?
Limits the results to messages with the given tenant IDs.
-
#trigger_data ⇒ String?
Limits the results to only messages that were generated with the given data.
-
#workflows ⇒ Array<String>?
Limits the results to messages with the given workflow keys.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
75 |
# File 'sig/knockapi/models/channels/bulk_update_message_status_params.rbs', line 75
def initialize: (
|
Instance Attribute Details
#action ⇒ Symbol, Knockapi::Models::Channels::BulkUpdateMessageStatusParams::Action
19 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 19 required :action, enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::Action } |
#archived ⇒ Symbol, ...
Limits the results to messages with the given archived status.
25 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 25 optional :archived, enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::Archived } |
#channel_id ⇒ String
14 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 14 required :channel_id, String |
#delivery_status ⇒ Symbol, ...
Limits the results to messages with the given delivery status.
31 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 31 optional :delivery_status, enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::DeliveryStatus } |
#engagement_status ⇒ Symbol, ...
Limits the results to messages with the given engagement status.
37 38 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 37 optional :engagement_status, enum: -> { Knockapi::Channels::BulkUpdateMessageStatusParams::EngagementStatus } |
#has_tenant ⇒ Boolean?
Limits the results to messages that have a tenant or not.
44 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 44 optional :has_tenant, Knockapi::Internal::Type::Boolean |
#newer_than ⇒ Time?
Limits the results to messages inserted after the given date.
50 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 50 optional :newer_than, Time |
#older_than ⇒ Time?
Limits the results to messages inserted before the given date.
56 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 56 optional :older_than, Time |
#recipient_ids ⇒ Array<String>?
Limits the results to messages with the given recipient IDs.
62 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 62 optional :recipient_ids, Knockapi::Internal::Type::ArrayOf[String] |
#tenants ⇒ Array<String>?
Limits the results to messages with the given tenant IDs.
68 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 68 optional :tenants, Knockapi::Internal::Type::ArrayOf[String] |
#trigger_data ⇒ String?
Limits the results to only messages that were generated with the given data. See trigger data filtering for more information.
76 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 76 optional :trigger_data, String |
#workflows ⇒ Array<String>?
Limits the results to messages with the given workflow keys.
82 |
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 82 optional :workflows, Knockapi::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/knockapi/models/channels/bulk_update_message_status_params.rb', line 128
|
Instance Method Details
#to_hash ⇒ {
91 |
# File 'sig/knockapi/models/channels/bulk_update_message_status_params.rbs', line 91
def to_hash: -> {
|