Module: Knockapi::Models::ObjectListSubscriptionsParams::Mode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/knockapi/models/object_list_subscriptions_params.rb,
sig/knockapi/models/object_list_subscriptions_params.rbs
Overview
Mode of the request. recipient to list the objects that the provided object is
subscribed to, object to list the recipients that subscribe to the provided
object.
Constant Summary collapse
- RECIPIENT =
:recipient- OBJECT =
:object
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Knockapi::Models::ObjectListSubscriptionsParams::mode]
105 |
# File 'sig/knockapi/models/object_list_subscriptions_params.rbs', line 105
def self?.values: -> ::Array[Knockapi::Models::ObjectListSubscriptionsParams::mode]
|