Class: Knockapi::Models::ObjectSetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::ObjectSetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/object_set_params.rb,
sig/knockapi/models/object_set_params.rbs
Overview
Instance Attribute Summary collapse
-
#channel_data ⇒ Hash{Symbol=>Knockapi::Models::Recipients::PushChannelDataTokensOnly, Knockapi::Models::Recipients::PushChannelDataDevicesOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataTargetArnsOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataDevicesOnly, Knockapi::Models::Recipients::OneSignalChannelDataPlayerIDsOnly, Knockapi::Models::Recipients::SlackChannelData, Knockapi::Models::Recipients::MsTeamsChannelData, Knockapi::Models::Recipients::DiscordChannelData}?
A request to set channel data for a type of channel inline.
- #collection ⇒ String
- #id ⇒ String
-
#locale ⇒ String?
The locale of the object.
-
#name ⇒ String?
An optional name for the object.
-
#preferences ⇒ Hash{Symbol=>Knockapi::Models::Recipients::PreferenceSetRequest}?
Inline set preferences for a recipient, where the key is the preference set id.
-
#timezone ⇒ String?
The timezone of the object.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(collection:, id:, channel_data: nil, locale: nil, name: nil, preferences: nil, timezone: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ObjectSetParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(collection:, id:, channel_data: nil, locale: nil, name: nil, preferences: nil, timezone: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Knockapi::Models::ObjectSetParams for more details.
|
|
# File 'lib/knockapi/models/object_set_params.rb', line 57
|
Instance Attribute Details
#channel_data ⇒ Hash{Symbol=>Knockapi::Models::Recipients::PushChannelDataTokensOnly, Knockapi::Models::Recipients::PushChannelDataDevicesOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataTargetArnsOnly, Knockapi::Models::Recipients::AwsSnsPushChannelDataDevicesOnly, Knockapi::Models::Recipients::OneSignalChannelDataPlayerIDsOnly, Knockapi::Models::Recipients::SlackChannelData, Knockapi::Models::Recipients::MsTeamsChannelData, Knockapi::Models::Recipients::DiscordChannelData}?
A request to set channel data for a type of channel inline.
24 25 |
# File 'lib/knockapi/models/object_set_params.rb', line 24 optional :channel_data, -> { Knockapi::Internal::Type::HashOf[union: Knockapi::Recipients::InlineChannelDataRequestItem] } |
#collection ⇒ String
13 |
# File 'lib/knockapi/models/object_set_params.rb', line 13 required :collection, String |
#id ⇒ String
18 |
# File 'lib/knockapi/models/object_set_params.rb', line 18 required :id, String |
#locale ⇒ String?
The locale of the object. Used for message localization.
32 |
# File 'lib/knockapi/models/object_set_params.rb', line 32 optional :locale, String, nil?: true |
#name ⇒ String?
An optional name for the object.
38 |
# File 'lib/knockapi/models/object_set_params.rb', line 38 optional :name, String, nil?: true |
#preferences ⇒ Hash{Symbol=>Knockapi::Models::Recipients::PreferenceSetRequest}?
Inline set preferences for a recipient, where the key is the preference set id. Preferences that are set inline will be merged into any existing preferences rather than replacing them.
46 |
# File 'lib/knockapi/models/object_set_params.rb', line 46 optional :preferences, -> { Knockapi::Internal::Type::HashOf[Knockapi::Recipients::PreferenceSetRequest] } |
#timezone ⇒ String?
The timezone of the object. Must be a valid tz database time zone string. Used for recurring schedules.
55 |
# File 'lib/knockapi/models/object_set_params.rb', line 55 optional :timezone, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/knockapi/models/object_set_params.rbs', line 52
def to_hash: -> {
|