Class: Knockapi::Models::Users::FeedListItemsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Users::FeedListItemsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/users/feed_list_items_params.rb,
sig/knockapi/models/users/feed_list_items_params.rbs
Overview
Defined Under Namespace
Modules: Archived, Mode, Status Classes: InsertedAt
Instance Attribute Summary collapse
-
#after ⇒ String?
The cursor to fetch entries after.
-
#archived ⇒ Symbol, ...
The archived status of the feed items.
-
#before ⇒ String?
The cursor to fetch entries before.
-
#exclude ⇒ String?
Comma-separated list of field paths to exclude from the response.
-
#has_tenant ⇒ Boolean?
Whether the feed items have a tenant.
- #id ⇒ String
- #inserted_at ⇒ Knockapi::Models::Users::FeedListItemsParams::InsertedAt?
-
#locale ⇒ String?
The locale to render the feed items in.
-
#mode ⇒ Symbol, ...
The mode to render the feed items in.
-
#page_size ⇒ Integer?
The number of items per page (defaults to 50).
-
#source ⇒ String?
The workflow key associated with the message in the feed.
-
#status ⇒ Symbol, ...
The status of the feed items.
-
#tenant ⇒ String?
The tenant associated with the feed items.
-
#trigger_data ⇒ String?
The trigger data of the feed items (as a JSON string).
- #user_id ⇒ String
-
#workflow_categories ⇒ Array<String>?
The workflow categories of the feed items.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Object
|
|
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 112
|
Instance Attribute Details
#after ⇒ String?
The cursor to fetch entries after.
25 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 25 optional :after, String |
#archived ⇒ Symbol, ...
The archived status of the feed items.
31 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 31 optional :archived, enum: -> { Knockapi::Users::FeedListItemsParams::Archived } |
#before ⇒ String?
The cursor to fetch entries before.
37 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 37 optional :before, String |
#exclude ⇒ String?
Comma-separated list of field paths to exclude from the response. Use dot
notation for nested fields (e.g., entries.archived_at). Limited to 3 levels
deep.
45 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 45 optional :exclude, String |
#has_tenant ⇒ Boolean?
Whether the feed items have a tenant.
51 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 51 optional :has_tenant, Knockapi::Internal::Type::Boolean |
#id ⇒ String
19 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 19 required :id, String |
#inserted_at ⇒ Knockapi::Models::Users::FeedListItemsParams::InsertedAt?
56 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 56 optional :inserted_at, -> { Knockapi::Users::FeedListItemsParams::InsertedAt } |
#locale ⇒ String?
The locale to render the feed items in. Must be in the IETF 5646 format (e.g.
en-US). When not provided, will default to the locale that the feed items were
rendered in. Only available for enterprise plan customers using custom
translations.
65 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 65 optional :locale, String |
#mode ⇒ Symbol, ...
The mode to render the feed items in. Can be compact or rich. Defaults to
rich. When mode is compact, feed items will not have activities and
total_activities fields; the data field will not include nested arrays and
objects; and the actors field will only have up to one actor.
74 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 74 optional :mode, enum: -> { Knockapi::Users::FeedListItemsParams::Mode } |
#page_size ⇒ Integer?
The number of items per page (defaults to 50).
80 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 80 optional :page_size, Integer |
#source ⇒ String?
The workflow key associated with the message in the feed.
86 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 86 optional :source, String |
#status ⇒ Symbol, ...
The status of the feed items.
92 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 92 optional :status, enum: -> { Knockapi::Users::FeedListItemsParams::Status } |
#tenant ⇒ String?
The tenant associated with the feed items.
98 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 98 optional :tenant, String |
#trigger_data ⇒ String?
The trigger data of the feed items (as a JSON string).
104 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 104 optional :trigger_data, String |
#user_id ⇒ String
14 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 14 required :user_id, String |
#workflow_categories ⇒ Array<String>?
The workflow categories of the feed items.
110 |
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 110 optional :workflow_categories, Knockapi::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/knockapi/models/users/feed_list_items_params.rb', line 158
|
Instance Method Details
#to_hash ⇒ {
117 |
# File 'sig/knockapi/models/users/feed_list_items_params.rbs', line 117
def to_hash: -> {
|