Class: Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Config
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Config
- Defined in:
- lib/knockapi/models/users/preference_center_get_config_response.rb,
sig/knockapi/models/users/preference_center_get_config_response.rbs
Overview
Defined Under Namespace
Classes: Row
Instance Attribute Summary collapse
-
#body ⇒ String
The body text displayed below the title.
-
#rows ⇒ Array<Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Config::Row>
An ordered list of rows to display in the preference center.
-
#show_account_name ⇒ Boolean?
Whether the account name should be displayed in the preference center.
-
#title ⇒ String
The title displayed at the top of the preference center.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
85 |
# File 'sig/knockapi/models/users/preference_center_get_config_response.rbs', line 85
def initialize: (
|
Instance Attribute Details
#body ⇒ String
The body text displayed below the title.
91 |
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 91 required :body, String |
#rows ⇒ Array<Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Config::Row>
An ordered list of rows to display in the preference center.
97 98 |
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 97 required :rows, -> { Knockapi::Internal::Type::ArrayOf[Knockapi::Models::Users::PreferenceCenterGetConfigResponse::Config::Row] } |
#show_account_name ⇒ Boolean?
Whether the account name should be displayed in the preference center.
110 |
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 110 optional :show_account_name, Knockapi::Internal::Type::Boolean |
#title ⇒ String
The title displayed at the top of the preference center.
104 |
# File 'lib/knockapi/models/users/preference_center_get_config_response.rb', line 104 required :title, String |
Instance Method Details
#to_hash ⇒ {
92 |
# File 'sig/knockapi/models/users/preference_center_get_config_response.rbs', line 92
def to_hash: -> {
|