Class: Knockapi::Models::WorkflowRecipientRun
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::WorkflowRecipientRun
- Defined in:
- lib/knockapi/models/workflow_recipient_run.rb,
sig/knockapi/models/workflow_recipient_run.rbs
Overview
Direct Known Subclasses
Defined Under Namespace
Modules: Status Classes: TriggerSource
Instance Attribute Summary collapse
-
#_typename ⇒ String
The typename of the schema.
-
#actor ⇒ String, ...
A reference to a recipient, either a user identifier (string) or an object reference (ID, collection).
-
#error_count ⇒ Integer?
The number of errors encountered during the workflow recipient run.
-
#id ⇒ String
The unique identifier for the workflow recipient run (per-recipient).
-
#inserted_at ⇒ Time
Timestamp when the resource was created.
-
#recipient ⇒ String, Knockapi::Models::RecipientReference::ObjectReference
A reference to a recipient, either a user identifier (string) or an object reference (ID, collection).
-
#status ⇒ Symbol, Knockapi::Models::WorkflowRecipientRun::Status
The current status of the workflow recipient run.
-
#tenant ⇒ String?
The tenant associated with the workflow recipient run.
-
#trigger_source ⇒ Knockapi::Models::WorkflowRecipientRun::TriggerSource
Describes how the workflow was triggered.
-
#updated_at ⇒ Time
The timestamp when the resource was last updated.
-
#workflow ⇒ String
The key of the workflow that was executed.
-
#workflow_run_id ⇒ String
The identifier for the top-level workflow run shared across all recipients in a single trigger.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, _typename:, inserted_at:, recipient:, status:, trigger_source:, updated_at:, workflow:, workflow_run_id:, actor: nil, error_count: nil, tenant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WorkflowRecipientRun for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, _typename:, inserted_at:, recipient:, status:, trigger_source:, updated_at:, workflow:, workflow_run_id:, actor: nil, error_count: nil, tenant: nil) ⇒ Object
Some parameter documentations has been truncated, see Knockapi::Models::WorkflowRecipientRun for more details.
A workflow recipient run represents an individual execution of a workflow for a specific recipient.
|
|
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 83
|
Instance Attribute Details
#_typename ⇒ String
The typename of the schema.
17 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 17 required :_typename, String, api_name: :__typename |
#actor ⇒ String, ...
A reference to a recipient, either a user identifier (string) or an object reference (ID, collection).
69 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 69 optional :actor, union: -> { Knockapi::RecipientReference }, nil?: true |
#error_count ⇒ Integer?
The number of errors encountered during the workflow recipient run.
75 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 75 optional :error_count, Integer |
#id ⇒ String
The unique identifier for the workflow recipient run (per-recipient).
11 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 11 required :id, String |
#inserted_at ⇒ Time
Timestamp when the resource was created.
23 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 23 required :inserted_at, Time |
#recipient ⇒ String, Knockapi::Models::RecipientReference::ObjectReference
A reference to a recipient, either a user identifier (string) or an object reference (ID, collection).
30 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 30 required :recipient, union: -> { Knockapi::RecipientReference } |
#status ⇒ Symbol, Knockapi::Models::WorkflowRecipientRun::Status
The current status of the workflow recipient run. One of queued, processing,
paused, completed, or cancelled.
37 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 37 required :status, enum: -> { Knockapi::WorkflowRecipientRun::Status } |
#tenant ⇒ String?
The tenant associated with the workflow recipient run.
81 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 81 optional :tenant, String, nil?: true |
#trigger_source ⇒ Knockapi::Models::WorkflowRecipientRun::TriggerSource
Describes how the workflow was triggered.
43 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 43 required :trigger_source, -> { Knockapi::WorkflowRecipientRun::TriggerSource } |
#updated_at ⇒ Time
The timestamp when the resource was last updated.
49 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 49 required :updated_at, Time |
#workflow ⇒ String
The key of the workflow that was executed.
55 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 55 required :workflow, String |
#workflow_run_id ⇒ String
The identifier for the top-level workflow run shared across all recipients in a single trigger.
62 |
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 62 required :workflow_run_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/knockapi/models/workflow_recipient_run.rb', line 127
|
Instance Method Details
#to_hash ⇒ {
61 |
# File 'sig/knockapi/models/workflow_recipient_run.rbs', line 61
def to_hash: -> {
|