Class: Knockapi::Models::WorkflowRecipientRunListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Knockapi::Models::WorkflowRecipientRunListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/knockapi/models/workflow_recipient_run_list_params.rb,
sig/knockapi/models/workflow_recipient_run_list_params.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#after ⇒ String?
The cursor to fetch entries after.
-
#before ⇒ String?
The cursor to fetch entries before.
-
#ending_at ⇒ Time?
Limits the results to workflow recipient runs started before the given date.
-
#has_errors ⇒ Boolean?
Limits the results to workflow recipient runs that have errors.
-
#page_size ⇒ Integer?
The number of items per page (defaults to 50).
-
#recipient ⇒ String, ...
Limits the results to workflow recipient runs for the given recipient.
-
#starting_at ⇒ Time?
Limits the results to workflow recipient runs started after the given date.
-
#status ⇒ Array<Symbol, Knockapi::Models::WorkflowRecipientRunListParams::Status>?
Limits the results to workflow recipient runs with the given status.
-
#tenant ⇒ String?
Limits the results to workflow recipient runs for the given tenant.
-
#workflow ⇒ String?
Limits the results to workflow recipient runs for the given workflow key.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
66 |
# File 'sig/knockapi/models/workflow_recipient_run_list_params.rbs', line 66
def initialize: (
|
Instance Attribute Details
#after ⇒ String?
The cursor to fetch entries after.
14 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 14 optional :after, String |
#before ⇒ String?
The cursor to fetch entries before.
20 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 20 optional :before, String |
#ending_at ⇒ Time?
Limits the results to workflow recipient runs started before the given date.
26 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 26 optional :ending_at, Time |
#has_errors ⇒ Boolean?
Limits the results to workflow recipient runs that have errors.
32 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 32 optional :has_errors, Knockapi::Internal::Type::Boolean |
#page_size ⇒ Integer?
The number of items per page (defaults to 50).
38 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 38 optional :page_size, Integer |
#recipient ⇒ String, ...
Limits the results to workflow recipient runs for the given recipient. Accepts a
user ID string or an object reference with id and collection.
45 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 45 optional :recipient, union: -> { Knockapi::RecipientReference } |
#starting_at ⇒ Time?
Limits the results to workflow recipient runs started after the given date.
51 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 51 optional :starting_at, Time |
#status ⇒ Array<Symbol, Knockapi::Models::WorkflowRecipientRunListParams::Status>?
Limits the results to workflow recipient runs with the given status.
57 58 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 57 optional :status, -> { Knockapi::Internal::Type::ArrayOf[enum: Knockapi::WorkflowRecipientRunListParams::Status] } |
#tenant ⇒ String?
Limits the results to workflow recipient runs for the given tenant.
64 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 64 optional :tenant, String |
#workflow ⇒ String?
Limits the results to workflow recipient runs for the given workflow key.
70 |
# File 'lib/knockapi/models/workflow_recipient_run_list_params.rb', line 70 optional :workflow, String |
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/knockapi/models/workflow_recipient_run_list_params.rbs', line 80
def to_hash: -> {
|