Class: Knockapi::Resources::Channels
- Inherits:
-
Object
- Object
- Knockapi::Resources::Channels
- Defined in:
- lib/knockapi/resources/channels.rb,
lib/knockapi/resources/channels/bulk.rb,
sig/knockapi/resources/channels.rbs,
sig/knockapi/resources/channels/bulk.rbs
Defined Under Namespace
Classes: Bulk
Instance Attribute Summary collapse
-
#bulk ⇒ Knockapi::Resources::Channels::Bulk
readonly
A bulk operation is a set of changes applied across zero or more records triggered via a call to the Knock API and performed asynchronously.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Channels
constructor
private
A new instance of Channels.
Constructor Details
#initialize(client:) ⇒ Channels
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Channels.
14 15 16 17 |
# File 'lib/knockapi/resources/channels.rb', line 14 def initialize(client:) @client = client @bulk = Knockapi::Resources::Channels::Bulk.new(client: client) end |
Instance Attribute Details
#bulk ⇒ Knockapi::Resources::Channels::Bulk (readonly)
A bulk operation is a set of changes applied across zero or more records triggered via a call to the Knock API and performed asynchronously.
9 10 11 |
# File 'lib/knockapi/resources/channels.rb', line 9 def bulk @bulk end |