Class: Knockapi::Resources::Providers
- Inherits:
-
Object
- Object
- Knockapi::Resources::Providers
- Defined in:
- lib/knockapi/resources/providers.rb,
lib/knockapi/resources/providers/slack.rb,
lib/knockapi/resources/providers/ms_teams.rb,
sig/knockapi/resources/providers.rbs,
sig/knockapi/resources/providers/slack.rbs,
sig/knockapi/resources/providers/ms_teams.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#ms_teams ⇒ Knockapi::Resources::Providers::MsTeams
readonly
A provider represents a third-party service that Knock integrates with and is configured via a channel.
-
#slack ⇒ Knockapi::Resources::Providers::Slack
readonly
A provider represents a third-party service that Knock integrates with and is configured via a channel.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Providers
constructor
private
A new instance of Providers.
Constructor Details
#initialize(client:) ⇒ Providers
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Providers.
19 20 21 22 23 |
# File 'lib/knockapi/resources/providers.rb', line 19 def initialize(client:) @client = client @slack = Knockapi::Resources::Providers::Slack.new(client: client) @ms_teams = Knockapi::Resources::Providers::MsTeams.new(client: client) end |
Instance Attribute Details
#ms_teams ⇒ Knockapi::Resources::Providers::MsTeams (readonly)
A provider represents a third-party service that Knock integrates with and is configured via a channel.
14 15 16 |
# File 'lib/knockapi/resources/providers.rb', line 14 def ms_teams @ms_teams end |
#slack ⇒ Knockapi::Resources::Providers::Slack (readonly)
A provider represents a third-party service that Knock integrates with and is configured via a channel.
9 10 11 |
# File 'lib/knockapi/resources/providers.rb', line 9 def slack @slack end |