Class: Knockapi::Resources::WorkflowRecipientRuns
- Inherits:
-
Object
- Object
- Knockapi::Resources::WorkflowRecipientRuns
- Defined in:
- lib/knockapi/resources/workflow_recipient_runs.rb,
sig/knockapi/resources/workflow_recipient_runs.rbs
Overview
A workflow run represents an individual execution of a workflow for a specific recipient.
Instance Method Summary collapse
-
#get(id, request_options: {}) ⇒ Knockapi::Models::WorkflowRecipientRunDetail
Returns a single workflow recipient run with its associated events.
-
#initialize(client:) ⇒ WorkflowRecipientRuns
constructor
private
A new instance of WorkflowRecipientRuns.
-
#list(after: nil, before: nil, ending_at: nil, has_errors: nil, page_size: nil, recipient: nil, starting_at: nil, status: nil, tenant: nil, workflow: nil, request_options: {}) ⇒ Knockapi::Internal::ItemsCursor<Knockapi::Models::WorkflowRecipientRun>
Some parameter documentations has been truncated, see Models::WorkflowRecipientRunListParams for more details.
Constructor Details
#initialize(client:) ⇒ WorkflowRecipientRuns
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of WorkflowRecipientRuns.
76 77 78 |
# File 'lib/knockapi/resources/workflow_recipient_runs.rb', line 76 def initialize(client:) @client = client end |
Instance Method Details
#get(id, request_options: {}) ⇒ Knockapi::Models::WorkflowRecipientRunDetail
Returns a single workflow recipient run with its associated events.
64 65 66 67 68 69 70 71 |
# File 'lib/knockapi/resources/workflow_recipient_runs.rb', line 64 def get(id, params = {}) @client.request( method: :get, path: ["v1/workflow_recipient_runs/%1$s", id], model: Knockapi::WorkflowRecipientRunDetail, options: params[:request_options] ) end |
#list(after: nil, before: nil, ending_at: nil, has_errors: nil, page_size: nil, recipient: nil, starting_at: nil, status: nil, tenant: nil, workflow: nil, request_options: {}) ⇒ Knockapi::Internal::ItemsCursor<Knockapi::Models::WorkflowRecipientRun>
Some parameter documentations has been truncated, see Models::WorkflowRecipientRunListParams for more details.
Returns a paginated list of workflow recipient runs for the current environment.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/knockapi/resources/workflow_recipient_runs.rb', line 40 def list(params = {}) parsed, = Knockapi::WorkflowRecipientRunListParams.dump_request(params) query = Knockapi::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "v1/workflow_recipient_runs", query: query, page: Knockapi::Internal::ItemsCursor, model: Knockapi::WorkflowRecipientRun, options: ) end |